#
# spec file for package wine
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           wine
BuildRequires:  Mesa-devel
BuildRequires:  alsa-devel
BuildRequires:  autoconf
BuildRequires:  bison
BuildRequires:  capi4linux-devel
BuildRequires:  cups-devel
BuildRequires:  dbus-1-devel
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  fontconfig-devel
BuildRequires:  freeglut-devel
BuildRequires:  freetype2-devel
BuildRequires:  giflib-devel
BuildRequires:  gstreamer-plugins-base-devel
BuildRequires:  libgnutls-devel
BuildRequires:  libgphoto2-devel
BuildRequires:  libgsm-devel
BuildRequires:  libjpeg-devel
BuildRequires:  liblcms2-devel
BuildRequires:  libpcap-devel
BuildRequires:  libpng-devel
BuildRequires:  libpulse-devel
BuildRequires:  libtiff-devel
BuildRequires:  libv4l-devel
BuildRequires:  libxml2-devel
BuildRequires:  libxslt-devel
BuildRequires:  ncurses-devel
BuildRequires:  openal-soft-devel
BuildRequires:  openldap2-devel
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig

# Marcus: remove it in devel too if you remove it here.
BuildRequires:  gcc48

BuildRequires:  sane-backends-devel
BuildRequires:  update-desktop-files
BuildRequires:  valgrind-devel
BuildRequires:  xorg-x11-devel
Version:        1.8.6
Release:        1.13
Summary:        An MS Windows Emulator
License:        LGPL-2.1+
Group:          System/Emulators/PC
Url:            http://www.winehq.org/
Source0:        http://downloads.sourceforge.net/project/wine/Source/wine-%{version}.tar.bz2
Source41:       wine.keyring
Source42:       http://downloads.sourceforge.net/project/wine/Source/wine-%{version}.tar.bz2.sign
Source1:        https://raw.githubusercontent.com/Winetricks/winetricks/master/src/winetricks
Source11:       https://raw.githubusercontent.com/Winetricks/winetricks/master/src/winetricks.1
Source2:        http://kegel.com/wine/wisotool
Source3:        README.SUSE
Source4:        wine.desktop
Source6:        wine-msi.desktop
Source5:        ubuntuwine.tar.bz2
Source7:        baselibs.conf
# SUSE specific patches
# - currently none, but add them here
#Patch0:         susepatches.patch
Recommends:     wine-gecko >= 2.24
Recommends:     wine-mp3
# not packaged in distro...
Recommends:     wine-mono
Recommends:     dosbox
Recommends:     alsa-plugins
Recommends:     alsa-plugins-pulse
Requires:       samba-winbind
Conflicts:      wine-gecko < 1.3
%ifarch x86_64
Requires:       %{name}-32bit = %{version}
%endif
# for winetricks:
Requires:       cabextract
Requires:       unzip
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExclusiveArch:  %{ix86} x86_64 ppc %arm

%description
An MS Windows emulator, consisting of both runtime and source
compatibility functions. You can run your MS executables with it and
write your Windows programs under Linux and link against the WINE
libraries.

It is not necessary to have a Windows installation to run WINE.

Refer to %{_datadir}/doc/packages/wine/README.SUSE. There is more
documentation available in that directory. Read 'man wine' for further
information.

You can invoke wine by entering 'wine program.exe'. Configure it by
running 'winecfg'.


%package devel
Summary:        files for wine development
Group:          System/Emulators/PC
Requires:       gcc48

%description devel
This RPM contains the header files and development tools for the WINE
libraries.

%prep
%setup -q
#%patch0 -p1
#
cp %{S:3} .
#

%build
cat VERSION
%ifarch %ix86
# e.g. Steam and other copy protections hate removed %ebp.
export RPM_OPT_FLAGS=`echo $RPM_OPT_FLAGS|sed -e 's/-fomit-frame-pointer//'`
%endif
# Until gcc 5 is fixed
export CC="gcc-4.8"

# keep just for susepatches with configure changes
#autoconf
#autoheader -I include
CFLAGS="$RPM_OPT_FLAGS" \
%configure \
	--with-x \
%ifarch x86_64
        --enable-win64 \
%endif
	--verbose

grep "have_x=yes" config.log || exit 1
# generate baselibs.conf
%ifarch %ix86
echo "# autogenerated in .spec file" >%SOURCE7
echo "%name" >> %SOURCE7
echo "  +^/usr/bin/wine\$" >> %SOURCE7
echo "  +^/usr/bin/wine-preloader\$" >> %SOURCE7
echo "  +^/usr/lib/wine/fakedlls" >> %SOURCE7
grep SONAME_ config.log
grep SONAME_ config.log|grep -v 'so"'|sed -e 's/^.*\(".*"\).*$/ requires \1/;'|sort -u >>%SOURCE7
echo " recommends \"alsa-plugins-pulse-32bit\""	>> %SOURCE7
echo " recommends \"alsa-plugins-32bit\""	>> %SOURCE7
%if 0%{?suse_version} >= 1310
echo " requires \"p11-kit-32bit\""		>> %SOURCE7
%endif
echo "%name-devel" >> %SOURCE7
echo "  +^/usr/lib/wine/.*def" >> %SOURCE7
cat %SOURCE7
%endif
make %{?_smp_mflags} all

%install
make install DESTDIR=%{buildroot}
# install desktop file
install -d %{buildroot}%{_datadir}/applications/
%suse_update_desktop_file %{SOURCE4} Emulator

install -m 0644 %SOURCE4 %{buildroot}%{_datadir}/applications/
install -m 0644 %SOURCE6 %{buildroot}%{_datadir}/applications/
install -m 0755 %SOURCE1 %{buildroot}%{_bindir}/
install -m 0755 %SOURCE2 %{buildroot}%{_bindir}/
mv %{buildroot}/%{_mandir}/de.UTF-8 %{buildroot}/%{_mandir}/de
mv %{buildroot}/%{_mandir}/fr.UTF-8 %{buildroot}/%{_mandir}/fr
%ifnarch x86_64
mv %{buildroot}/%{_mandir}/pl.UTF-8 %{buildroot}/%{_mandir}/pl
%endif
install -c %{SOURCE11} %{buildroot}/%{_mandir}/man1/

tar xjf %{SOURCE5}
# Copied from Ubuntu Wine out of debian.diff
# https://launchpad.net/~ubuntu-wine/+archive/ppa/+packages
# taken on 1.2rc2 time.
cd ubuntuwine
        install -d %{buildroot}%{_sysconfdir}/xdg/menus/applications-merged
        install -c -m 644 wine.menu %{buildroot}%{_sysconfdir}/xdg/menus/applications-merged

        # Install application-specific desktop files
        install -d %{buildroot}%{_datadir}/applications
        install -c -m 644 *.desktop %{buildroot}%{_datadir}/applications/

        install -d %{buildroot}%{_datadir}/desktop-directories/
        install -c -m 644 *.directory %{buildroot}%{_datadir}/desktop-directories/

        # Install icons
        install -d %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/
        install -c -m 644 *.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/
cd ..

# find the implicit dependencies
%define winedir %_builddir/%name-%version/
cat >%winedir/my-find-requires.sh <<EOF
#!/bin/bash
%{__find_requires}
%ifarch x86_64
grep SONAME_ %winedir/config.log|grep -v 'so"'|sed -e 's/^.*"\(.*\)".*$/\1()(64bit)/;'|sort -u
%else
grep SONAME_ %winedir/config.log|grep -v 'so"'|sed -e 's/^.*"\(.*\)".*$/\1/;'|sort -u
%endif
EOF
chmod 755 %winedir/my-find-requires.sh
%define _use_internal_dependency_generator 0
%define __find_requires %winedir/my-find-requires.sh

# breaks btrfs installation, see bnc#723402
# %fdupes -s %{buildroot}

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc ANNOUNCE AUTHORS LICENSE LICENSE.OLD README* 
%{_bindir}/function_grep.pl
%{_bindir}/msiexec
%{_bindir}/notepad
%{_bindir}/regedit
%{_bindir}/regsvr32
%{_bindir}/wineboot
%{_bindir}/winecfg
%{_bindir}/wineconsole
%{_bindir}/winedbg
%{_bindir}/winefile
%{_bindir}/winemine
%{_bindir}/winepath
%{_bindir}/wineserver
%{_bindir}/winetricks
%{_bindir}/wisotool
%{_datadir}/wine
%{_datadir}/applications/wine.desktop
%ifnarch x86_64
%doc %{_mandir}/man1/wine.1*
%endif
%doc %{_mandir}/man1/winedbg.1*
%doc %{_mandir}/man1/wineserver.1*
%ifnarch x86_64
%doc %dir %doc %{_mandir}/pl
%doc %dir %doc %{_mandir}/pl/man1
%doc %{_mandir}/*/man1/wine.1*
%endif
%doc %{_mandir}/*/man1/wineserver.1*
%doc %{_mandir}/man1/msiexec.1.*
%doc %{_mandir}/man1/notepad.1.*
%doc %{_mandir}/man1/regedit.1.*
%doc %{_mandir}/man1/regsvr32.1.*
%doc %{_mandir}/man1/wineboot.1.*
%doc %{_mandir}/man1/winebuild.1.*
%doc %{_mandir}/man1/winecfg.1.*
%doc %{_mandir}/man1/wineconsole.1.*
%doc %{_mandir}/man1/winecpp.1.*
%doc %{_mandir}/man1/winefile.1.*
%doc %{_mandir}/man1/winemine.1.*
%doc %{_mandir}/man1/winetricks.1.*
%doc %{_mandir}/man1/winepath.1.*
%dir %{_sysconfdir}/xdg/menus/
%dir %{_sysconfdir}/xdg/menus/applications-merged
%config %{_sysconfdir}/xdg/menus/applications-merged/*.menu
%{_datadir}/applications/*.desktop
%dir %{_datadir}/desktop-directories/
%{_datadir}/desktop-directories/*.directory 
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/scalable
%dir %{_datadir}/icons/hicolor/scalable/apps
%{_datadir}/icons/hicolor/scalable/apps/*.svg
%ifarch %ix86
%{_bindir}/wine
%{_bindir}/wine-preloader
%endif
%ifarch ppc %arm
%{_bindir}/wine
%endif
%ifarch x86_64
%{_bindir}/wine64
%{_bindir}/wine64-preloader
%endif
%{_libdir}/wine/*.so
%{_libdir}/lib*.so.*
%dir %{_libdir}/wine
%dir %{_libdir}/wine/fakedlls
%{_libdir}/wine/fakedlls/*

%files devel
%defattr(-,root,root)
%{_includedir}/wine
%{_bindir}/widl
%{_bindir}/winebuild
%{_bindir}/winecpp
%{_bindir}/winedump
%{_bindir}/wineg++
%{_bindir}/winegcc
%{_bindir}/winemaker
%{_bindir}/wmc
%{_bindir}/wrc
%{_libdir}/wine/*.def
%{_libdir}/wine/*.a
%{_libdir}/lib*.so
%doc %{_mandir}/man1/winemaker.1*
%doc %{_mandir}/*/man1/winemaker.1*
%doc %{_mandir}/man1/widl.1*
%doc %{_mandir}/man1/winedump.1*
%doc %{_mandir}/man1/wineg++.1*
%doc %{_mandir}/man1/winegcc.1*
%doc %{_mandir}/man1/wmc.1*
%doc %{_mandir}/man1/wrc.1*

# %{_datadir}/aclocal/wine.m4

%changelog
* Wed Dec 21 2016 meissner@suse.com
- Updated to 1.8.6 release (bsc#960661)
  - Fix a regression introduced in 1.8.5 (#41627)
  - Various bug fixes.
  - Small translation updates.
- updated winetricks
* Sat Nov 12 2016 meissner@suse.com
- Updated to 1.8.5 release (bsc#960661)
  - Various bug fixes.
  - Small translation updates.
- updated winetricks
* Mon Aug 22 2016 meissner@suse.com
- Updated to 1.8.4 release (bsc#960661)
  - Various bug fixes.
  - Small translation updates.
- updated winetricks
* Thu Jun 16 2016 meissner@suse.com
- Updated to 1.8.3 release (bsc#960661)
  - Various bug fixes.
  - Small translation updates.
- updated winetricks
* Tue Apr 12 2016 meissner@suse.com
- Updated to 1.8.2 release (bsc#960661)
  - Various bug fixes.
  - Small translation updates.
- updated winetricks
- wine.keyring: use new key from alexandre
* Thu Feb  4 2016 meissner@suse.com
- Updated to 1.8.1 release (bsc#960661)
  - Various bug fixes.
  - Small translation updates.
- updated winetricks
* Fri Jan 22 2016 meissner@suse.com
- Updated to 1.8 Release (bsc#960661)
  This release represents 17 months of development effort and around
  13,000 individual changes. The main highlights are the implementation
  of DirectWrite and Direct2D, and the new Pulse Audio driver.
- updated winetricks
- updated some buildrequires
* Fri Oct  2 2015 meissner@suse.com
- Updated to 1.7.52 development snapshot
  - Unicode data updated to Unicode 8.0.0.
  - Some implementation of the Web Services DLL.
  - More Direct3D 11 interfaces.
  - A few more functions in the C++ runtime.
  - Output standard glyph names in the PostScript driver.
  - Various bug fixes.
- updated winetricks
* Fri Sep  4 2015 meissner@suse.com
- Updated to 1.7.51 development snapshot
  - XAudio2 implementation using OpenAL Soft.
  - Support for the new Universal C Runtime DLL.
  - Dropdown menu support in the standard Open Dialog.
  - Grayscale rendering mode in DirectWrite.
  - Various bug fixes.
- winetricks helper script updated
* Mon Aug 31 2015 meissner@suse.com
- have -devel require gcc48 too, as winegcc directly gets it. bsc#943841
* Mon Aug 24 2015 meissner@suse.com
- Updated to 1.7.50 development snapshot
  - New version of the Gecko engine based on Firefox 40.
  - First steps of the Direct3D 11 implementation.
  - Better font matching in DirectWrite.
  - Support for OpenMP on ARM platforms.
  - Various bug fixes.
- updated winetricks
- removed susepatches.patch (upstreamed)
* Thu Aug 13 2015 meissner@suse.com
- susepatches.patch: fix ms word
* Sat Aug  8 2015 meissner@suse.com
- Updated to 1.7.49 development snapshot
  - DirectWrite is now good enough for rendering text in Steam.
  - A number of Direct2D improvements.
  - Some more OpenMP functions.
  - Support for namespaces in the IDL compiler.
  - Various bug fixes.
- winetricks update
* Wed Jul 29 2015 meissner@suse.com
- Updated to 1.7.48 development snapshot
  - Fleshed out OpenMP implementation.
  - I/O stream support in the MSVCIRT C++ runtime.
  - Support for pixel snapping in DirectWrite.
  - More support for OpenGL core contexts.
  - Various bug fixes.
- winetricks update
* Fri Jul 10 2015 meissner@suse.com
- Updated to 1.7.47 development snapshot
  - Text drawing in Direct2D.
  - Support for the new thread pool API.
  - Toolbar state saving.
  - Beginnings of an implementation for proper HID support.
  - Support for file objects in device drivers.
  - Various bug fixes.
- winetricks update
* Tue Jul  7 2015 meissner@suse.com
- use gcc-4.8 for building, as gcc5 miscompiles wine currently.
* Fri Jun 26 2015 meissner@suse.com
- Updated to 1.7.46 development snapshot
  - Improvements in the BITS file transfer service.
  - Still more progress on DirectWrite implementation.
  - Support for shared user data on 64-bit.
  - Various C++ runtime improvements.
  - Some more support for the 64-bit ARM platform.
  - Various bug fixes.
* Sat Jun 13 2015 meissner@suse.com
- susepatches.patch: fix build on x86_64
* Fri Jun 12 2015 meissner@suse.com
- Updated to 1.7.45 development snapshot
  - Better debugging support on 64-bit Mac OS X.
  - Some more progress on DirectWrite implementation.
  - A number of RichEdit control fixes.
  - Beginning implementation of the old MSVCIRT C++ runtime.
  - Various bug fixes.
* Sun Jun  7 2015 meissner@suse.com
- buildrequire new dependency libunwind-devel.
* Sun May 31 2015 hillwood@opensuse.org
- Updated to 1.7.44 development snapshot
  - More support for the COM interfaces of the RichEdit control.
  - Initial version of a SmartTee filter.
  - Some more support for the ARM64 platform.
  - Support for the null device kernel object.
  - Various bug fixes.
- updated winetricks
* Fri May 15 2015 meissner@suse.com
- Updated to 1.7.43 development snapshot
  - Improved support for Shell Browser windows.
  - Some more API Sets libraries.
  - Read/write operations support with built-in devices.
  - Major Catalan translation update.
  - Support for WoW64 mode on ARM64.
  - Various bug fixes.
- updated winetricks
* Fri May  1 2015 meissner@suse.com
- Updated to 1.7.42 development snapshot
  - Support for dynamic timezone information.
  - Initial desktop shell window support.
  - Some more Direct2D support.
  - Various bug fixes.
- updated winetricks
* Fri Apr 17 2015 meissner@suse.com
- Updated to 1.7.41 development snapshot
  - More Known Folders supported in the shell.
  - Some more support for kernel job objects.
  - More MSI patches improvements.
  - Some theming fixes.
  - Various bug fixes.
- updated winetricks
* Sun Apr  5 2015 meissner@suse.com
- Updated to 1.7.40 development snapshot
  - Support for kernel job objects.
  - Various fixes to the ListView control.
  - Better support for OOB data in Windows Sockets.
  - Support for DIB images in the OLE data cache.
  - Improved support for MSI patches.
  - Some fixes for ACL file permissions.
  - Various bug fixes.
* Fri Mar 27 2015 meissner@suse.com
- switch from gstream 010 to gstreamer-plugins-base-devel (current)
  bsc#924632
* Tue Mar 24 2015 meissner@suse.com
- updated winetricks script to 20150316, they moved to github:
  https://github.com/Winetricks/winetricks
* Fri Mar 20 2015 meissner@suse.com
- Updated to 1.7.39 development snapshot
  - WinMM joystick support on Mac OS X.
  - Kerning support in DirectWrite.
  - Support for DirectX Media Objects filters.
  - Better support for animated GIFs in GdiPlus.
  - Improved support for Known Folders in Shell32.
  - Various bug fixes.
* Fri Mar  6 2015 meissner@suse.com
- Updated to 1.7.38 development snapshot
  - New version of the Gecko engine based on Firefox 36.
  - Support for themed scrollbars.
  - Updated version of the Mono engine.
  - More compatible RPC interface for service control.
  - Support for X Drag & Drop version 5.
  - Threading fixes in IME support.
  - Various bug fixes.
* Fri Feb 20 2015 meissner@suse.com
- Updated to 1.7.37 development snapshot
  - Interface change notifications.
  - Support for the UTF-7 encoding.
  - A number of graphical fixes for themed controls.
  - Wininet now implemented on top of Win32 sockets.
  - Various bug fixes.
* Sat Feb  7 2015 meissner@suse.com
- Updated to 1.7.36 development snapshot
  - Some preliminary 64-bit support for Mac OS X.
  - Support for configuring speakers in Winecfg.
  - Improved support for Mac OS X Trash folder.
  - Support for typographic features in DirectWrite.
  - Various bug fixes.
* Fri Jan 23 2015 meissner@suse.com
- Updated to 1.7.35 development snapshot
  - Beginnings of support for OpenGL core contexts.
  - Initial support for glyph placement in DirectWrite.
  - Some more WBEM objects.
  - Various bug fixes.
* Fri Jan  9 2015 meissner@suse.com
- Updated to 1.7.34 development snapshot
  - Support for surround sound in DirectSound.
  - Better text run support in DirectWrite.
  - Many HTML engine fixes.
  - More support for WBEM objects.
  - A few more C/C++ runtime functions.
  - Various bug fixes.
* Fri Dec 12 2014 meissner@suse.com
- Updated to 1.7.33 development snapshot
  - Support for copy/paste commands in MSHTML.
  - Some more font support in DirectWrite.
  - Better handling for loss of focus in Direct3D windows.
  - Several more API Sets DLLs.
  - Various bug fixes.
* Fri Nov 28 2014 meissner@suse.com
- Updated to 1.7.32 development snapshot
  - New version of the Mono engine.
  - A few more functions implemented in MSHTML.
  - Improved support for restoring display mode.
  - Font metrics improvements in DirectWrite.
  - Various bug fixes.
- updated winetricks to current version
* Sun Nov 16 2014 meissner@suse.com
- remove gpg-offline usage as its checked by the source services
* Fri Nov 14 2014 meissner@suse.com
- Updated to 1.7.31 development snapshot
  - New version of the Gecko engine based on Firefox 34.
  - Support for the Visual Studio 2013 version of the C/C++ runtimes.
  - More font metrics support in DirectWrite.
  - Some more Direct2D work.
  - Various bug fixes.
* Sat Nov  1 2014 meissner@suse.com
- Updated to 1.7.30 development snapshot
  - Support for shaping and BiDi mirroring in DirectWrite.
  - Some page fault handling fixes.
  - A few more C runtime functions.
  - Various bug fixes.
- updated winetricks
* Sun Oct 19 2014 Led <ledest@gmail.com>
- fix bashisms in wisotool script
* Fri Oct 17 2014 meissner@suse.com
- Updated to 1.7.29 development snapshot
  - Support for shaping and BiDi mirroring in DirectWrite.
  - Some page fault handling fixes.
  - A few more C runtime functions.
  - Various bug fixes.
* Fri Oct  3 2014 meissner@suse.com
- Updated to 1.7.28 development snapshot
  - Support for conditional compilation in JavaScript.
  - Bidirectional text support in DirectWrite.
  - Stubs for DirectPlay Voice support.
  - Various bug fixes.
* Fri Sep 19 2014 meissner@suse.com
- Updated to 1.7.27 development snapshot
  - Some more work on Direct2D support.
  - Various improvements to RichEdit interfaces.
  - Initial support for ICMP version 6.
  - Various bug fixes.
* Sat Sep  6 2014 meissner@suse.com
- Updated to 1.7.26 development snapshot
  - Still more DirectWrite functions.
  - Improvements to the common File Dialog.
  - A number of C runtime improvements.
  - Various bug fixes.
- updated winetricks
* Fri Aug 22 2014 meissner@suse.com
- Updated to 1.7.25 development snapshot
  - Implementation of the packet capture library.
  - A few more DirectWrite functions.
  - Improvements in HTML table support.
  - More VBScript math functions.
  - Various bug fixes.
- buildrequire libpcap-devel for wpcap.dll
* Mon Aug 11 2014 meissner@suse.com
- Updated to 1.7.24 development snapshot
  - Beginning of some DirectWrite classes implementation.
  - Initial wrapper dll for the packet capture library.
  - Some crypto improvements.
  - Various bug fixes.
- updated winetricks
* Sat Jul 26 2014 meissner@suse.com
- Updated to 1.7.23 development snapshot
  - Better support for files drag & drop.
  - Improvements to the HTTP cookie management.
  - Initial support for 64-bit Android builds.
  - Fixes to crypto certificates management.
  - Various bug fixes.
- updated winetricks
* Sun Jul 13 2014 meissner@suse.com
- Updated to 1.7.22 development snapshot
  - Support for Unicode bracketing pairs.
  - Improved Internet cookie support.
  - OS X CoreAudio driver uses AUHAL instead of AudioQueue.
  - Initial support for geographical information.
  - Various bug fixes.
- updated winetricks
* Fri Jun 27 2014 meissner@suse.com
- Updated to 1.7.21 development snapshot
  - Support for critical sections in the C runtime.
  - Unicode data updated to Unicode 7.0.
  - Support for interlaced PNG encoding.
  - Initial stub for the Packager library.
  - Various bug fixes.
* Fri Jun 13 2014 meissner@suse.com
- Updated to 1.7.20 development snapshot
  - X11 drag & drop fixes.
  - A few more C/C++ runtime functions.
  - Fixes for various memory issues found by Valgrind.
  - Some OLE storage fixes.
  - Various bug fixes.
- winetricks updated
* Mon May 19 2014 meissner@suse.com
- Updated to 1.7.19 development snapshot
  - New JSProxy DLL for automatic proxy configuration.
  - More OLE Accessible Object support.
  - Improvements to the XML writer.
  - Fixes for various memory issues found by Valgrind.
  - Initial headers for Direct2D support.
  - Various bug fixes.
- winetricks updated
* Fri May  2 2014 meissner@suse.com
- Updated to 1.7.18 development snapshot
  - Improved OLE Accessible Object support.
  - Window sizing improvements in the Mac driver.
  - Fixes for various memory issues found by Valgrind.
  - A few more MSHTML functions.
  - Some DirectDraw cleanups.
  - Various bug fixes.
- winetricks updated
* Fri Apr 18 2014 meissner@suse.com
- Updated to 1.7.17 development snapshot
  - More implementations for the Task Scheduler.
  - C runtime made more compatible by sharing source files.
  - Fixes in the Mac OS X joystick support.
  - Various bug fixes.
- updated winetricks
* Fri Apr  4 2014 meissner@suse.com
- Updated to 1.7.16 development snapshot
  - More regression test fixes.
  - String arrays better supported in the IDL compiler.
  - Initial stubs for DirectX Video Acceleration.
  - Various bug fixes.
* Fri Mar 21 2014 meissner@suse.com
- Updated to 1.7.15 development snapshot
  - New Task Scheduler service.
  - Many regression test fixes.
  - Support for exception unwinding in VBScript.
  - Various bug fixes.
* Fri Mar  7 2014 meissner@suse.com
- Updated to 1.7.14 development snapshot
  - More Task Scheduler support.
  - Improvements for AVI encoding support.
  - More VisualBasic interfaces in MSXML.
  - Support for deflate content encoding in Wininet.
  - Some fixes for monochrome printers.
  - Various bug fixes.
* Sat Feb 22 2014 meissner@suse.com
- Updated to 1.7.13 development snapshot
  - More Task Scheduler support.
  - A few more Direct3D 10 interfaces.
  - More Windows Media Player stubs.
  - ARM code generation improvements.
  - Better memory size reporting on Mac OS X.
  - Various bug fixes.
- updated winetricks, added manpage
* Fri Feb  7 2014 meissner@suse.com
- Updated to 1.7.12 development snapshot
  - Initial support for Window Media Player interfaces.
  - Some more Task Scheduler support.
  - Various C++ runtime fixes.
  - More dlls with ugly names for Windows 8 API set support.
  - Various bug fixes.
* Fri Jan 24 2014 meissner@suse.com
- require p11-kit-32bit in -32bit package.
* Fri Jan 17 2014 meissner@suse.com
- Updated to 1.7.11 development snapshot
  - Uniscribe support in the RichEdit control.
  - Support for condition variables and Slim Reader/Writer locks.
  - More D3D command stream preparation work.
  - Optional Start Menu in desktop mode.
  - Improved support for vertical fonts metrics.
  - Various bug fixes.
* Tue Jan  7 2014 meissner@suse.com
- recommend alsa-plugins-pulse and alsa-plugins for the x86 -32bit
  package, otherwise there would be no sound.
  bnc#857621
* Sat Jan  4 2014 meissner@suse.com
- Updated to 1.7.10 development snapshot
  - Window maximization in the Mac driver.
  - AVI compressor implementation.
  - Thread local storage support in dynamically loaded libraries.
  - Beginnings of a Task Scheduler implementation.
  - Extended IPX protocol support.
  - Various bug fixes.
- require samba-winbind for the ntlm_auth helper binary
  bnc#857302
* Fri Dec 20 2013 meissner@suse.com
- Updated to 1.7.9 development snapshot
  - Improved window moving/resizing in the Mac driver.
  - Some DirectDraw palette fixes.
  - Reduced code duplication between C++ runtime versions.
  - Various bug fixes.
* Sat Dec  7 2013 meissner@suse.com
- Updated to 1.7.8 development snapshot
  - Updated version of the Mono package.
  - Improvements in the BITS service implementation.
  - Better data tables for Japanese vertical fonts support.
  - Improved backtraces on recent Mac OS X versions.
  - Various bug fixes.
* Sun Nov 24 2013 meissner@suse.com
- Updated to 1.7.7 development snapshot
  - Support for configuring remote shares using Samba's NetAPI library.
  - Multiple keyboard layouts support in the Mac driver.
  - Improved embedding support through XEMBED.
  - Support for arrays in VBScript.
  - Various bug fixes.
* Fri Nov  8 2013 meissner@suse.com
- Updated to 1.7.6 development snapshot
  - Rewrite of the BiDi algorithm for full Unicode 6.3 support.
  - Support for Video Mixing Renderer version 7.
  - Better handling of window resizes in the Mac driver.
  - Various bug fixes.
* Fri Oct 25 2013 meissner@suse.com
- Updated to 1.7.5 development snapshot
  - Support for registration-free COM using activation contexts.
  - Improved support for simulated bold fonts.
  - Unicode data updated to Unicode 6.3.
  - Better support for typelib registration on 64-bit.
  - Various bug fixes.
* Fri Oct 11 2013 meissner@suse.com
- Updated to 1.7.4 development snapshot
  - Support for Cocoa-style full-screen mode in the Mac driver.
  - More preparation work for the Direct3D command stream.
  - A number of Winsock improvements.
  - Various bug fixes.
* Fri Sep 27 2013 meissner@suse.com
- Updated to 1.7.3 development snapshot
  - New version of the Gecko engine based on Firefox 24.
  - Preparation work for the Direct3D command stream.
  - Window management fixes in the Mac driver.
  - Support for IPHLPAPI functions on Android.
  - Various bug fixes.
* Fri Sep 27 2013 meissner@suse.com
- split off a wine-msi.desktop for installing MSI packages.
  bnc#695105
* Wed Sep 18 2013 meissner@suse.com
- Updated to 1.7.2 development snapshot
  - Right-to-left text layout improvements.
  - NTLM and Negotiate authentication for RPC over HTTP.
  - More glyphs in the built-in Wingdings font.
  - Better system tray support in the Mac driver.
  - Activation context improvements.
  - Various bug fixes.
* Sat Aug 31 2013 meissner@suse.com
- Updated to 1.7.1 development snapshot
  - Support for keyed event objects.
  - Support for the "init once" synchronization mechanism.
  - Activation context support for DLLs, typelibs, and COM classes.
  - Support for loading 32-bit typelibs on 64-bit.
  - Various Mac driver fixes.
  - Some fixes for serial port devices.
  - Various bug fixes.
* Tue Aug  6 2013 meissner@suse.com
- Updated to 1.7.0 development release
  - Support for vertical text in the Postscript driver.
  - Version 2 of liblcms used now instead of version 1.
  - Unicode data updated to Unicode 6.2.0.
  - Hyperlink controls supported in installers.
  - Improved support for XML attributes.
  - Various bug fixes.
- buildrequire liblcms2-devel now instead of liblcms-devel
* Tue Jul 30 2013 meissner@suse.com
- enable armv7l
* Fri Jul 19 2013 meissner@suse.com
- Updated to 1.6 Release.
  This release represents 16 months of development effort and around
  10,000 individual changes. The main highlights are the new Mac driver,
  the full support for window transparency, and the new Mono package for
  .NET applications support.
  It also contains a lot of improvements across the board, as well as
  support for many new applications and games. See the release notes
  for a summary of the major changes.
- winetricks helper script updated
* Fri Jun  7 2013 meissner@suse.com
- updated to 1.6rc1 beta snapshot.
  - New implementation of the typelib creation support.
  - GLSL-based support for fixed function vertex shaders.
  - Support for desktop launchers in virtual desktop mode.
  - Fixes for Japanese vertical text.
  - New Croatian translation.
  - Various bug fixes.
- more 1.6rcs with just bugfixes
* Fri May 24 2013 meissner@suse.com
- Updated to 1.5.31 development snapshot.
  - New version of the Gecko engine based on Firefox 21.
  - Joystick force feedback support on Mac OS X.
  - Window management fixes in the Mac driver.
  - Various bug fixes.
* Fri May 10 2013 meissner@suse.com
- Updated to 1.5.30 development snapshot.
  - Mouse capture support in the Mac driver.
  - NTLM and Negotiate authentication in WinHTTP.
  - Support for proxy bypass in WinInet.
  - Various bug fixes.
- susepatches.patch: Fixed a build issue.
* Sun Apr 28 2013 meissner@suse.com
- Updated to 1.5.29 development snapshot.
  - Input method support in the Mac driver.
  - Support for TLS 1.1 and 1.2 connections on Mac OS X.
  - JavaScript performance improvements.
  - Various bug fixes.
* Fri Apr 12 2013 meissner@suse.com
- Updated to 1.5.28 development snapshot.
  - GnuTLS used for all secure connections, OpenSSL is no longer needed.
  - Mac driver enabled by default.
  - Built-in FixedSys fonts.
  - New icon for the joystick control panel.
  - Postscript driver improvements.
  - Various bug fixes.
- Updated to 1.5.27 development snapshot
  - System tray support in the Mac driver.
  - Various C runtime improvements.
  - Large icons for built-in applications.
  - Various bug fixes.
* Tue Apr  2 2013 meissner@suse.com
- Updated to 1.5.26 development snapshot
  - System tray support in the Mac driver.
  - Various C runtime improvements.
  - Large icons for built-in applications.
  - Various bug fixes.
* Fri Mar  1 2013 meissner@suse.com
- Updated to 1.5.25 development snapshot
  - Proper cursor support in the Mac driver.
  - Fixes for right-to-left support in RichEdit.
  - Initial version of a Wingdings font.
  - Various bug fixes.
- enabled gpg verification
* Fri Feb 15 2013 meissner@suse.com
- Updated to 1.5.24 development snapshot
  - Keyboard and mouse wheel support in the Mac driver.
  - Regular expression support in VB Script.
  - Many RichEdit code cleanups.
  - Various bug fixes.
* Fri Feb  1 2013 meissner@suse.com
- Updated to 1.5.23 development snapshot
  - HTTPS support no longer dependent on OpenSSL.
  - Support for event handling in the Mac driver.
  - A functional Netstat built-in application.
  - A bunch of C++ runtime math functions.
  - Various bug fixes.
* Fri Jan 18 2013 meissner@suse.com
- Updated to 1.5.22 development snapshot
  - New version of the Gecko engine.
  - Beginnings of the Mac graphics driver.
  - Support for ARM64 platforms.
  - Fixes for RTL text in Uniscribe.
  - Various bug fixes.
- require new wine-gecko version > 1.9
* Sun Jan  6 2013 meissner@suse.com
- Updated to 1.5.21 development snapshot
  - Beginnings of a netstat built-in program.
  - Support for selecting resolution in the PostScript driver.
  - Various bug fixes.
* Sat Dec 22 2012 meissner@suse.com
- Updated to 1.5.20 development snapshot
  - A bunch of dlls with ugly names for API sets support.
  - More ATL functions implemented.
  - Still more C++ runtime functions.
  - Several text rendering fixes.
  - PostScript driver improvements.
  - Various bug fixes.
* Sat Dec  8 2012 meissner@suse.com
- Updated to 1.5.19 development snapshot.
  - Performance improvements in the DIB engine.
  - More fleshed out XML-lite implementation.
  - Some more C++ runtime functions.
  - Various bug fixes.
* Mon Nov 26 2012 jengelh@inai.de
- Parallel build with %%_smp_mflags
* Fri Nov 23 2012 meissner@suse.com
- Updated to 1.5.18 development snapshot.
  - Various Windows Codecs improvements.
  - Fixes for OLE database support.
  - Improvements to system parameters management.
  - Some fixes to the built-in Web browser.
  - Fixes for XML support.
  - Various bug fixes.
* Sun Nov 11 2012 meissner@suse.com
- Updated to 1.5.17 development snapshot.
  - Sub-pixel font anti-aliasing in the DIB engine.
  - Support for automatic installation of ActiveX controls.
  - Automatic fallback to TLS 1.0 for secure connections.
  - Beginnings of the DirectWrite text analyzer.
  - Better handling of font outlines in OpenGL.
  - Various bug fixes.
* Fri Oct 26 2012 meissner@suse.com
- Updated to 1.5.16 development snapshot
  - New version of the Mono package.
  - Many improvements to the CMD command-line parser.
  - More stream classes in the C++ runtime.
  - Support for managing services in WMI.
  - Improved CPU detection.
  - Various bug fixes.
* Fri Oct 12 2012 meissner@suse.com
- Updated to 1.5.15 development snapshot
  - Full support for layered windows.
  - New version of the Gecko engine based on Firefox 16.
  - Support for broadcast sockets used by networked games.
  - Downloaded add-ons installers are now cached.
  - Support for persistent Internet cookies.
  - String optimizations in JavaScript.
  - Various bug fixes.
- require wine-gecko >= 1.8
* Fri Sep 28 2012 meissner@suse.com
- Updated to 1.5.14 development snapshot
  - Much better behavior of the URL cache.
  - Improved GIF image support.
  - More parser features in the shader compiler.
  - Optimizations in JavaScript.
  - Various bug fixes.
- updated winetricks to 20120912
* Fri Sep 14 2012 meissner@suse.com
- Updated to 1.5.13 development snapshot
  - Client-side window rendering using the DIB engine.
  - Raw input support for keyboard and mouse.
  - Support for transparent window areas using color keying.
  - Proper C++ RTTI support on 64-bit.
  - Implementation of logical processor information.
  - Support for fonts with localized names.
  - Various bug fixes.
* Fri Aug 31 2012 meissner@suse.com
- Updated to 1.5.12 development snapshot
  - Support for disabling individual joysticks.
  - Better support for D3DX9 constant tables.
  - Some XRandR improvements.
  - Various bug fixes.
* Tue Aug 21 2012 meissner@suse.com
- updated winetricks
* Mon Aug 20 2012 dmueller@suse.com
- package bin/wine on %%arm
- prelink is only needed for %%ix86 and x86_64 (win32 and win64)
  (not yet for ARM)
* Fri Aug 17 2012 meissner@suse.com
- Updated to 1.5.11 development snapshot
  - Multi-channel support in the ALSA driver.
  - Removal of the big X11 lock.
  - Support for pair positioning adjustments in Uniscribe.
  - More I/O stream implementations in the C++ runtime.
  - Various bug fixes.
* Tue Jul 31 2012 meissner@suse.com
- Updated to 1.5.10 development snapshot
  - New version of the Gecko engine based on Firefox 14.
  - Support for OpenGL in the DIB engine using libOSMesa.
  - Off-screen rendering is now the default in Direct3D.
  - Some more WMI infrastructure.
  - Various bug fixes.
* Wed Jul 18 2012 meissner@suse.com
- Updated to 1.5.9 development snapshot
  - Support for GPOS font tables in Uniscribe.
  - Support for XRandr 1.2 and 1.3.
  - Parser improvements for the HLSL compiler.
  - More key exchange algorithms supported on Mac OS.
  - Relay tracing on ARM.
  - Various bug fixes.
* Tue Jul  3 2012 meissner@suse.com
- Updated to 1.5.8 development snapshot
  - More stream functionality in the C++ runtime.
  - A number of Windows Codecs improvements.
  - More WBEM classes and properties.
  - Some HTML Help fixes.
  - Support for printing fake italic fonts.
  - Various bug fixes.
* Tue Jul  3 2012 meissner@suse.com
- updated winetricks to current version
* Sun Jun 24 2012 meissner@suse.com
- Updated to 1.5.7 development snapshot
  - New version of the Gecko engine based on Firefox 13.
  - Dynamic device support with UDisks2.
  - More stream classes implemented in the C++ runtime.
  - Support for metadata in TIFF files.
  - Fleshed out WBEM implementation.
  - Improved support for printer paper sizes.
  - Various bug fixes.
- wine gecko 1.6 now required (see above)
* Mon Jun 11 2012 meissner@suse.com
- Updated to 1.5.6 development snapshot
  - Automatic installation of the Mono add-on package.
  - Control panel applet for joysticks.
  - Device bitmap rendering now done through the DIB engine.
  - Support for video rendering through DirectX (VMR-9).
  - First steps towards a D3D shader compiler.
  - Build fixes for DragonFly BSD.
  - Various bug fixes.
* Fri May 25 2012 meissner@suse.com
- Updated to 1.5.5 development snapshot
  - Support for installing Mono as a Wine add-on package.
  - Dithering of pattern brushes in the DIB engine.
  - Support for installing the .NET 4.0 runtime.
  - DDS files supported in D3DX9.
  - Various bug fixes.
- updated winetricks
* Mon May 21 2012 badshah400@gmail.com
- Use BuildRequires: libgnutls-devel instead of gnutls-devel for
  Factory in keeping with gnutls package naming changes.
* Wed May 16 2012 meissner@suse.de
- Use .*def as regexp instead of glob *.def
* Sat May 12 2012 meissner@suse.de
- Updated to 1.5.4 development snapshot
  - A new DirectSound resampler.
  - A Negotiate authentication provider.
  - OpenGL support in the DIB engine.
  - Beginnings of support for .NET mixed assemblies.
  - Support routines for Internationalized Domain Names.
  - Various bug fixes.
* Fri Apr 27 2012 meissner@suse.de
- Updated to 1.5.3 development snapshot
  - Support for graphics bounds tracking.
  - A number of fixes to the builtin Internet Explorer.
  - Support for displaying ARM code in the Wine debugger.
  - Various DirectMusic improvements.
  - Better namespace support in MSXML.
  - Various bug fixes.
* Fri Apr 13 2012 meissner@suse.de
- Updated to 1.5.2 development snapshot
  - Improved naming scheme for audio devices.
  - Better support for finding system fonts on Mac OS X.
  - Beginnings of support for JPEG encoding.
  - Several printing fixes.
  - Improvements to the URL cache.
  - Various bug fixes.
* Thu Apr  5 2012 reddwarf@opensuse.org
- Include /usr/lib/wine/*.def files in wine-devel-32bit
* Fri Mar 30 2012 meissner@suse.de
- Updated to 1.5.1 development snapshot
  - Built-in JavaScript now preferred over Gecko in most cases.
  - Support for scalable font resources.
  - Fixes for audio and video playback.
  - Support for script decoding in JScript.
  - Various bug fixes.
* Mon Mar 26 2012 meissner@suse.de
- Updated to 1.5.0 development snapshot (use Emulators:Wine:STABLE for wine 1.4)
  - New version of the Gecko engine.
  - Partial support for using the Trash on Mac OS X.
  - Support for path gradients in GdiPlus.
  - Various MSXML improvements.
  - Fixes to 64-bit exception handling.
  - Various bug fixes.
* Tue Mar 13 2012 meissner@suse.de
- Updated winetricks to 20120308
* Wed Mar  7 2012 meissner@suse.de
- Wine 1.4 final release
  This release represents 20 months of development effort and over
  16,000 individual changes. The main highlights are the new DIB
  graphics engine, a redesigned audio stack, and full support for
  bidirectional text and character shaping.
* Fri Feb 17 2012 meissner@suse.de
- Updated to 1.4-rc4 release candidate (1.3.38_1.4rc4 for linearity)
  - Bug fixes only, we are in code freeze.
* Mon Feb 13 2012 meissner@suse.de
- Updated to 1.4-rc3 release candidate (1.3.38_1.4rc3 for linearity)
  - Bug fixes only, we are in code freeze.
* Mon Feb  6 2012 meissner@suse.de
- Updated to 1.4-rc2 release candidate (1.3.38_1.4rc2 for linearity)
  - Bug fixes only, we are in code freeze.
* Tue Jan 31 2012 meissner@suse.de
- disable fdupes as then install on btrfs will not work. bnc#723402
* Fri Jan 27 2012 meissner@suse.com
- Updated to 1.4-rc1 release candidate (1.3.38_1.4rc1 for linearity)
  - Improved crash dialog with support for saving the backtrace.
  - Support for the Back button in built-in Internet Explorer.
  - Keyboard accelerators can now be translated through po files.
  - A number of installer fixes.
  - Many translation updates and tweaks.
  - Various bug fixes.
* Thu Jan 26 2012 meissner@suse.com
- autogenerate baselibs.conf
* Mon Jan 16 2012 meissner@suse.de
- Updated to 1.3.36 development snapshot
  - Completion of the DIB engine.
  - Improvements to the C++ runtime.
  - A number of fixes in the audio drivers.
  - Unnecessary Direct3D options removed from WineCfg.
  - Some fixes to the built-in Internet Explorer.
  - Various bug fixes.
- packaging changed to use baselibs methods
* Fri Dec 30 2011 meissner@suse.com
- Updated to 1.3.36 development snapshot
  - UDisks backend for the dynamic device support.
  - Polygons and geometric pens implemented in the DIB engine.
  - JScript now compiles entire functions.
  - Improved support for vertical fonts.
  - A few more scripts in UniScribe.
  - A bunch of ctype functions implemented in MSVCP.
  - Various bug fixes.
* Wed Dec 21 2011 coolo@suse.com
- add autoconf as buildrequire to avoid implicit dependency
* Sat Dec 17 2011 meissner@suse.com
- Updated to 1.3.35 development snapshot
  - Triangular gradients and cosmetic wide pens support in the DIB engine.
  - All Wine dialogs can now be translated through po files.
  - Many more scripts added to UniScribe.
  - JScript using bytecode throughout now.
  - Several MSXML improvements.
  - Various bug fixes.
* Fri Dec  2 2011 meissner@suse.de
- Updated to 1.3.34 development snapshot
  - Bytecode support in JavaScript.
  - Support for gradients in the DIB engine.
  - A number of Uniscribe improvements.
  - Fixes for DirectDraw mode switching.
  - A few more MSVC runtime functions.
  - Various bug fixes.
* Mon Nov 21 2011 meissner@suse.de
- Remove -fomit-frame-pointer again.
* Fri Nov 18 2011 meissner@suse.de
- Updated to 1.3.33 development snapshot
  - Support for text output in the DIB engine.
  - Improved support for HTTP proxies.
  - New version of the Gecko engine.
  - A number of cursor fixes.
  - Some fixes in bidirectional text layout.
  - Various bug fixes.
* Sun Nov  6 2011 meissner@suse.de
- Updated to 1.3.32 development snapshot
  - BiDi text support in the multi-line edit control.
  - Support for pattern brushes in the DIB engine.
  - A number of MSXML fixes.
  - Improvements to the PostScript driver.
  - Various bug fixes.
* Fri Oct 21 2011 meissner@suse.de
- Updated to 1.3.31 development snapshot
  - BiDi text support in the single-line edit control.
  - Support for StretchDIBits and AlphaBlend in the DIB engine.
  - A number of audio fixes.
  - VBScript improvements.
  - Various bug fixes.
- Updated winetricks
* Tue Oct 18 2011 meissner@suse.de
- Updated to 1.3.30 development snapshot
  - DirectSound reimplemented on top of MMDevAPI.
  - Support for StretchBlt in the DIB engine.
  - User interface improvements in HTML help.
  - Some MSXML fixes.
  - Performance improvements in cmd.
  - Various bug fixes.
* Sat Oct 15 2011 andrea.turrini@gmail.com
- fixed typo in wine.spec
* Tue Oct  4 2011 meissner@suse.de
- recommend dosbox as it is used when vm86 is not present.
* Sun Sep 25 2011 meissner@suse.de
- Updated to 1.3.29 development snapshot
  - Extensive support for VBScript.
  - Various improvements to the calendar common control.
  - A number of XRender fixes and optimizations.
  - Several new functions in the MSVCP runtime.
  - A number of audio fixes.
  - DirectDraw cleanups.
  - Various bug fixes.
* Sun Sep 11 2011 meissner@suse.de
- Updated to 1.3.28 development snapshot
  - Initial version of the VBScript parser.
  - Automagic audio driver selection.
  - Support for volume information on UDF file systems.
  - The OpenGL renderer is now the default for DirectDraw.
  - Device configuration dialog in DirectInput.
  - SetDIBitsToDevice support in the DIB engine.
  - Several improvements in the cmd parser.
  - Various bug fixes.
* Wed Aug 31 2011 meissner@suse.de
- Updated to 1.3.27 development snapshot
  - Support for multisampling in Direct3D.
  - New version of the Gecko engine.
  - Improvements to the network proxy handling.
  - Better write support in MSXML.
  - Side-by-side manifests for built-in libraries.
  - Various bug fixes.
* Sat Aug  6 2011 meissner@suse.de
- Updated to 1.3.26 development snapshot
  - Various improvements to the builtin Internet Explorer.
  - Support for Get/SetDIBits in the DIB engine.
  - Support for enhanced metafiles in the View tool.
  - Many improvements in WinHTTP.
  - A number of fixes to the COM stubless marshaller.
  - Improved mechanism for DLL registrations.
  - Various bug fixes.
* Sat Jul 23 2011 meissner@suse.de
- Updated to 1.3.25 development snapshot
  - Rewrite of the audio support, using the Win7 architecture.
  - Old-style sound drivers for Jack, NAS and ESD are removed.
  - Graphics driver architecture changes for the DIB engine.
  - Improved handling of the shell recycle bin.
  - Better joystick support in DirectInput.
  - Initial stub for VBScript support.
  - Various bug fixes.
* Fri Jul  8 2011 meissner@suse.de
- Updated to 1.3.24 development snapshot
  - Various DirectInput improvements.
  - Support for line breaking in Uniscribe.
  - More UI elements in builtin Shell Explorer.
  - Some more D3DX9 functions.
  - Improved support for shell known folders.
  - Various bug fixes.
- libv4l headers no longer are in glibc, but in libv4l on factory
- updated winetricks to 20110629
* Wed Jun 29 2011 meissner@suse.de
- Updated to 1.3.23 development snapshot
  - Support for stubless COM proxies on x86-64.
  - Builtin dxdiag now outputs real information.
  - Monochrome bitmap format in the DIB engine.
  - Beginnings of a true shell Explorer builtin.
  - A number of new D3DX9 functions.
  - More support for Indic text shaping.
  - Various bug fixes.
* Wed Jun 29 2011 meissner@suse.de
- fixed pl man path
* Tue Jun 28 2011 lnussel@suse.de
- make hal support optional, default off (bnc#697035)
* Fri Jun 10 2011 meissner@suse.de
- Updated to 1.3.22 development snapshot
  - Support for Indic text shaping.
  - Generation of stubless code in the IDL compiler.
  - Support for X files in D3DX.
  - 4- and 24-bit bitmap formats in the DIB engine.
  - Listview performance improvements.
  - Various bug fixes.
* Fri May 27 2011 meissner@suse.de
- Updated to 1.3.21 development snapshot
  - Support for installation rollbacks in MSI.
  - 8- and 16-bit bitmap formats in the DIB engine.
  - Fixes in the XInput2 mouse support.
  - Better support for text shaping in Uniscribe.
  - Improvements to the Item common dialog.
  - More MSVC runtime functions.
  - Various bug fixes.
* Mon May 16 2011 meissner@suse.de
- escape a single \ with \\ in the wine-browsedrive.desktop file.
* Sat May 14 2011 meissner@suse.de
- Updated to 1.3.20 development snapshot
  - Option to clip the mouse inside fullscreen windows.
  - Support for persistent HTTP connections.
  - Initial implementation of the XML writer.
  - Support for drawing rectangles in the DIB engine.
  - Volume control in MMDevAPI.
  - More MSVC runtime functions.
  - Various bug fixes.
- updated winetricks
* Fri Apr 29 2011 meissner@suse.de
- Updated to 1.3.19 development snapshot
  - New sound driver architecture for MMDevAPI.
  - Better support for relative mouse events in DInput.
  - Debugger support for the ARM platform.
  - Various improvements in D3DX9.
  - More MSVC runtime functions.
  - Various bug fixes.
* Fri Apr 29 2011 meissner@novell.com
- Updated winetricks
* Fri Apr 15 2011 meissner@suse.de
- Updated to 1.3.18 development snapshot
  - Support for mouse pointer clipping.
  - Raw mouse events support using XInput2.
  - First steps of a DIB engine implementation.
  - More properties supported in DXDiag.
  - New security tab in the Internet control panel.
  - Improved video playback on Mac OS X.
  - Various bug fixes.
- Updated winetricks
* Fri Apr  1 2011 meissner@suse.de
- Updated to 1.3.17 development snapshot
  - Implementation of the new Vista file dialogs.
  - Initial support for patching in MSI installers.
  - Improvements to the calendar control.
  - A few fixes for file associations.
  - Menus cleaned up in built-in applications.
  - Various bug fixes.
- Updated winetricks
* Fri Mar 18 2011 meissner@suse.de
- Updated to 1.3.16 development snapshot
  - New version of the Gecko engine, based on Firefox 4.
  - Better support for Dwarf debugging information.
  - Improved handling of animated cursors.
  - GnuTLS no longer required on Mac OS X.
  - Improvements to the GDI driver infrastructure.
  - A number of MSI fixes for the .NET installers.
  - Several GdiPlus improvements.
  - Various bug fixes.
- new winetricks release
* Sat Mar  5 2011 meissner@suse.de
- Updated to 1.3.15 development snapshot
  - Support for changing network passwords.
  - Reflection support in shader compiler.
  - Tests no longer attempt to cope with Win9x behavior.
  - A number of MSHTML and MSXML improvements.
  - Various bug fixes.
* Sat Feb 19 2011 meissner@suse.de
- Updated to 1.3.14 development snapshot
  - Many cleanups to address Valgrind and Clang warnings.
  - Support for creating compressed cabinet files.
  - Translation updates.
  - Various bug fixes.
* Fri Feb  4 2011 meissner@suse.de
- Updated to 1.3.13 development snapshoamrcust
  - Tools for creating MSI installers.
  - Clipboard improvements.
  - Support for po files in the message compiler.
  - Improvements to the Wine debugger.
  - Various bug fixes.
* Sun Jan 23 2011 meissner@suse.de
- Updated to 1.3.12 development snapshot
  - Support for multiple icon sizes in winemenubuilder.
  - Improvements to the help browser.
  - Initial stab at DOSBox integration.
  - Various MSI fixes.
  - Some fixes to the Wine debugger.
  - Various bug fixes.
- updated winetricks
* Tue Jan 11 2011 meissner@suse.de
- one more fix for ppc build
* Fri Jan  7 2011 meissner@suse.de
- Updated to 1.3.11 development snapshot
  - PO files now used for translations.
  - Various JavaScript improvements.
  - Some fixes to the Wine debugger.
  - Translation updates.
  - Various bug fixes.
* Fri Jan  7 2011 meissner@suse.de
- moved development tools into -devel package
* Mon Jan  3 2011 meissner@suse.de
- Updated to 1.3.10 development snapshot
  - Support for notification balloons in system tray.
  - Obsolete AudioIO sound driver removed.
  - More work on ActiveX support.
  - Various MSI fixes.
  - Preloader now used for 64-bit too.
  - Translation updates.
  - Various bug fixes.
* Mon Jan  3 2011 meissner@novell.com
- little fix for PowerPC build.
* Sat Dec 11 2010 meissner@suse.de
- Updated to 1.3.9 development snapshot
  - Beginnings of support for ActiveX in built-in browser.
  - Icons on Internet shortcut menu entries.
  - Standardization of code implementing COM interfaces.
  - New scheme for auto-generated DLL registrations.
  - OpenCL library wrapper.
  - Translation updates.
  - Various bug fixes.
* Sat Nov 27 2010 meissner@novell.com
- Updated to 1.3.8 development snapshot
  - Icons in the "open with" menus.
  - Man pages for all installed binaries.
  - Support for schemas in MSXML.
  - Many installer fixes.
  - Translation updates.
  - Various bug fixes.
* Sun Nov 21 2010 meissner@suse.de
- updated winetricks to 20101106
- updated wisotool to 20101106
* Sat Nov 13 2010 meissner@novell.com
- Updated to 1.3.7 development snapshot
  - Improved system tray support.
  - Better support for installers with assemblies.
  - Many of the msvcrt "secure" functions implemented.
  - A lot of fixes to the GStreamer support.
  - Many MSXML improvements.
  - Translation updates.
  - Various bug fixes.
* Fri Oct 29 2010 meissner@suse.de
- Updated to 1.3.6 development snapshot
  - Support for GStreamer filters.
  - Mapping of standard cursors to native desktop cursors.
  - Improved support for installers with services.
  - Many MSXML improvements.
  - Decoder for TGA-format images.
  - Translation updates.
  - Various bug fixes.
* Tue Oct 26 2010 meissner@suse.de
- nodisplay=true in the .desktop file, so you can click on .exes again
  bnc#625365
* Tue Oct 26 2010 meissner@suse.de
- fixed wine.desktop
* Sun Oct 24 2010 meissner@suse.de
- add gstreamer-0_10-devel
* Fri Oct 15 2010 meissner@novell.com
- Updated to 1.3.5 development snapshot
  - Support for animated cursors.
  - Printing directly through CUPS instead of lpr.
  - Installer fixes for Office 2010.
  - Many MSXML3 improvements.
  - Improved Shader Model 4 support.
  - Proper icons in built-in Internet Explorer.
  - Translation updates.
  - Various bug fixes.
* Thu Oct 14 2010 meissner@suse.de
- fixed the icons for the menu entries
* Sat Oct  9 2010 meissner@suse.de
- explicitly filter -fomit-frame-pointer as it breaks some
  copy protections or hooks in Steam.
* Fri Oct  1 2010 meissner@suse.de
- Updated to 1.3.4 development snapshot
  - Support for right-to-left mirrored windows.
  - Winelib now supports the ARM platform.
  - New taskkill.exe built-in application.
  - Inetcpl control panel fleshed out.
  - AcceptEx is implemented now.
  - Improved security checks for SSL connections.
  - Translation updates.
  - Various bug fixes.
* Mon Sep 20 2010 meissner@suse.de
- Updated to 1.3.3 development snapshot
  - Improved support for right-to-left text.
  - Support for CMYK JPEG images.
  - Beginnings of a Game Explorer implementation.
  - Improved 64-bit support in MSI.
  - Stub inetcpl control panel applet.
  - A number of fixes to crypto support.
  - Translation updates.
  - Various bug fixes.
- updated winetricks
* Wed Sep 15 2010 aj@suse.de
- Change BuildRequires for sane-backends devel split.
* Mon Sep  6 2010 meissner@suse.de
- Updated to 1.3.2 development snapshot
  - Update of the Gecko engine, now including a 64-bit version.
  - New implementation of console support on Unix terminals.
  - Many new functions in the C runtime dlls.
  - Various bug fixes.
- updated winetricks
* Sun Aug 22 2010 meissner@suse.de
- Updated to 1.3.1 development snapshot
  - Support for drag & drop between X11 and OLE.
  - New ipconfig.exe builtin tool.
  - Support for favorites in builtin Internet Explorer.
  - Beginnings of a shell Explorer control.
  - A number of DirectDraw code cleanups.
  - Improvements to the calendar control.
  - Various bug fixes.
* Sun Aug  1 2010 meissner@suse.de
- Updated to 1.3.0 development snapshot
  - Beginnings of a user interface for the builtin Internet Explorer.
  - Support for cross-process OLE drag & drop.
  - New builtin wscript.exe (Windows Script Host) program.
  - Open/save dialogs remember the last used directory.
  - Translation updates.
  - Various bug fixes.
- updated winetricks
  - various new loaders
  - bugfixes
- updated wisotool
  - lots of fixes
* Fri Jul 16 2010 meissner@suse.de
- Updated to 1.2 Release
* Mon Jul  5 2010 meissner@suse.de
- updated to 1.2 rc6
  - Many translation updates.
  - A lot of bug fixes.
* Fri Jun 25 2010 meissner@suse.de
- updated to 1.2 rc5
  - Many translation updates.
  - A lot of bug fixes.
- updated winetricks to current state (minor bugfixes)
- updated wisotools to current state
* Tue Jun 22 2010 meissner@suse.de
- moved scalable icons to /usr/share/icons/hicolor/scalable/apps
* Fri Jun 18 2010 meissner@suse.de
- updated to 1.2 rc4
  - Many translation updates.
  - A lot of bug fixes.
- Added Ubuntu supplied desktop , menu and icons for
  Wine stuff. bnc#613850
* Fri Jun 11 2010 meissner@suse.de
- updated to 1.2 rc3
  - Many translation updates.
  - A lot of bug fixes.
- updated winetricks
  - utorrent downloader
  - some bugfixes
- updated wisotool
  - lots of improvements
* Fri May 28 2010 meissner@suse.de
- Updated to 1.2rc2
  - Lots of bugfixes
* Tue May 25 2010 meissner@suse.de
- Updated to 1.2rc1 (named 1.1.45_1.2rc1 to satisfy RPM)
  - Many new toolbar icons.
  - Support for alpha blending in image lists.
  - Much more complete shader assembler.
  - Support for Arabic font shaping and joining.
  - A number of fixes for video rendering.
  - Font antialiasing configuration through fontconfig.
  - Improved handling of desktop link files.
  - Various bug fixes.
* Fri May  7 2010 meissner@suse.de
- Updated to 1.1.44
  - Many more new icons.
  - Support for 32-bit prefixes with a 64-bit Wine.
  - Many additional msvcr80/90 functions.
  - Improvements to Bidi handling.
  - More complete mmdevapi (Win7 audio) support.
  - Improved handling of MSI patches.
  - A number of fixes for desktop menus.
  - Optimizations in OLE storage.
  - Various bug fixes.
* Sun Apr 25 2010 meissner@suse.de
- updated winetricks
  - lots of bugfixes and several additions
- added new wisotool
  - for easier installation of some known ISOs setups
* Mon Apr 19 2010 meissner@suse.de
- Updated to 1.1.43
  - A number of new icons.
  - Improved support for alpha channel in bitmaps.
  - Many Direct3D fixes and optimizations.
  - More complete msvcr80/90 implementations.
  - A wide range of 64-bit fixes.
  - Various bug fixes.
- Enabled 64bit packaging.
  - "wine" package can now be either 64 or 32bit.
  - "wine-32bit" package is the 32bit runtime system
    which is used by both 32bit and 64bit wine packages.
    It is required to run 32bit binaries.
* Fri Apr  2 2010 meissner@suse.de
- Updated to 1.1.42
  - Support for shared 32/64-bit setups.
  - Dwarf debug info support for better backtraces.
  - More standard actions supported in MSI.
  - Support for TIFF image format in WinCodecs.
  - A number of Direct3D improvements.
  - Shell fixes for better Internet Explorer support.
  - Various bug fixes.
* Fri Mar 19 2010 meissner@suse.de
- Updated to 1.1.41
  - A wide range of Direct3D improvements.
  - Support for SHA-256, SHA-384, and SHA-512 algorithms.
  - A number of MSHTML fixes.
  - Support for mp3 decoding on Mac OS X.
  - Various widl improvements.
  - More typelib fixes.
  - OLE storage improvements.
  - Various bug fixes.
- Updated winetricks
* Wed Mar 17 2010 meissner@suse.de
- updated winetricks
  - win7 handling
  - some new downloaders, some non working ones adjusted
* Fri Mar  5 2010 meissner@suse.de
- Updated to 1.1.40
  - Support for Wow64 registry redirection.
  - Increased coverage of MSI standard actions.
  - Various Wordpad improvements.
  - Many shell fixes for better IE support.
  - Improved support for typelibs.
  - Better GL card detection.
  - Various bug fixes.
- recommend wine-mp3
* Fri Feb 19 2010 meissner@suse.de
- Updated to 1.1.39
  - Support for registry symbolic links.
  - Many MSI fixes.
  - Build process improvements.
  - MSXML cleanups and fixes.
  - A number of MSHTML improvements.
  - Various bug fixes.
* Thu Feb 18 2010 meissner@suse.de
- fixed gcc 4.5 issue
* Fri Feb  5 2010 meissner@suse.de
- Updated to 1.1.38
  - Better support for memory allocations debugging.
  - Improved MIDI support.
  - A wide range of Direct3D fixes.
  - OLEDB fixes (should fix Clipart in Office).
  - Improved debugger support on x86-64.
  - Many MSI fixes.
  - Various bug fixes.
- updated winetricks
* Fri Jan 22 2010 meissner@suse.de
- Updated to 1.1.37
  - A number of fixes in AVI file support.
  - Several MSXML improvements.
  - A few MSI fixes.
  - Various bug fixes.
* Fri Jan  8 2010 meissner@suse.de
- Updated to 1.1.36
  - Completion of the 16-bit separation.
  - Improved Shader Model 4 support.
  - A ton of memory leak fixes.
  - Improved debugging support for MinGW.
  - A number of MSHTML fixes.
  - Various bug fixes.
* Fri Dec 18 2009 meissner@suse.de
- Updated to 1.1.35
  - Support for OLE transacted storage.
  - Better certificate checking on secure connections.
  - More progress on the 16-bit separation.
  - Left 4 Dead 2 DRM really supported now.
  - MSI performance improvements.
  - 64-bit fixes in debugger support.
  - Various bug fixes.
* Mon Dec 14 2009 meissner@suse.de
- winetricks update
  - fixed multiple downloaders, including quicktime, flash
* Fri Dec  4 2009 meissner@suse.de
- Updated to 1.1.34
  - Many fixes for crypto certificates support.
  - A lot of MSHTML improvements.
  - Various fixes to support the Left 4 Dead 2 DRM.
  - A number of OLE marshalling fixes.
  - More Listview improvements.
  - Various bug fixes.
* Thu Nov 26 2009 meissner@suse.de
- new winetricks release
  - Add experimental dotnet35 verb
  - Add IE7 verb. Based on a patch by Hans Leidekker.
  - Add verbs alsa, audioio, coreaudio, esound, jack, nas, oss to override
    sound driver
  - Add verbs backbuffer, fbo, pbuffer for setting offscreen rendering buffer
  - Don't crash winecfg if native comctl32 is used
  - Fix gecko to work with wine-1.1.33.
  - Make vc2003toolkit and psdk2003 verbs run on windows
  - On cleanup, remove $WINETRICKS_TMP, not just the files in it
  - Sorted command menu
  - Update Firefox to 3.5.5
  - Update mpc to latest version, move the exe to Program Files and add it to %%PATH%%
* Sat Nov 14 2009 meissner@suse.de
- Updated to 1.1.33
  - Gecko now installed at wineprefix creation time.
  - Better support for certificates in crypt32.
  - Improved sound support in mciwave.
  - Some more Direct3D 10 functions.
  - Many cleanups for issues spotted by Valgrind.
  - Various bug fixes.
* Fri Nov 13 2009 meissner@suse.de
- buildrequire "wine-gecko" prepackaged gecko engine,
  so it does not need to be seperately downloaded.
* Sun Nov  8 2009 meissner@suse.de
- starting to build for 64bit on Factory and later.
* Fri Oct 23 2009 meissner@suse.de
- Updated to 1.1.32
  - Many crypto fixes, particularly on 64-bit.
  - Improved DVD access on Mac OS.
  - Several common controls improvements.
  - Various HTML support improvements.
  - More DIB optimizations.
  - Various bug fixes.
* Fri Oct  9 2009 meissner@suse.de
- Updated to 1.1.31
  - Vastly improved monthcal control.
  - Performance improvements for DIB sections.
  - Several sound driver fixes.
  - Beginning of ActiveX support in JScript.
  - More Direct3D 10 work.
  - More 16-bit dlls split off to separate modules.
  - Support for attachments in MAPI.
  - Various bug fixes.
- updated winetricks
* Fri Sep 25 2009 meissner@suse.de
- Updated to 1.1.30
  - Support for OpenAL.
  - Many improvements in HTML and JavaScript support.
  - Many common controls fixes and improvements.
  - More Direct3D 10 work.
  - Better MAPI support.
  - Various bug fixes.
- updated winetricks
* Fri Sep  4 2009 meissner@suse.de
- Updated to 1.1.29
  - Improved Gecko integration by using Wine's network layers.
  - Use of external libmpg123 for mp3 decoding.
  - Support for JPEG and PNG formats in WindowsCodecs.
  - Many regression test fixes for Win64 and Windows 7.
  - Various bug fixes.
- updated winetricks
* Fri Aug 21 2009 meissner@suse.de
- Updated to 1.1.28
  - Support for IRDA protocol.
  - Faster initial wineprefix creation.
  - Axis remapping with evdev joysticks.
  - More image formats in WindowsCodecs.
  - Various bug fixes.
- updated winetricks
* Fri Aug  7 2009 meissner@suse.de
- Updated to upstream 1.1.27
  - New version of the Gecko engine.
  - New GSM 06.10 codec support.
  - Improved support for the disk volume APIs.
  - Support for XShm pixmaps for better performance.
  - Various bug fixes.
- added libgsm-devel to buildrequires
* Sat Jul 18 2009 meissner@suse.de
- Updated to upstream 1.1.26
  - Still more translation updates.
  - Faster bitmap stretching using XRender.
  - Proxy support in WinHTTP.
  - Many more JScript functions.
  - Various bug fixes.
* Sat Jul  4 2009 meissner@novell.com
- spec file cleanup, make it possible to rpmbuild -ba
  on x86_64 machines. bnc#519192
- Updated to upstream 1.1.25
  - A ton of translation updates.
  - Support for various Unicode file encodings in Notepad.
  - Improved memory management, especially for OpenGL.
  - Desktop menus now cleaned up automatically.
  - Beginnings of a windowscodecs DLL implementation.
  - Various bug fixes.
* Sun Jun 21 2009 meissner@suse.de
- Updated to upstream 1.1.24
  - Support for freedesktop file associations.
  - Support for exception handling on 64-bit.
  - Improved ARB shaders.
  - Fixes for the FBO mode.
  - Many listview improvements.
  - Various bug fixes.
- added hardrequires libgnutls.so.26 for schannel.dll.
- updated winetricks script
* Sun Jun  7 2009 meissner@suse.de
- Updated to upstream 1.1.23
  - Support for registering MIME types with the Linux desktop.
  - FBO mode is now the default for Direct3D.
  - Support for COM proxy delegation.
  - Improved support for the Mingw cross-compile.
  - Proper fullscreen mode for the virtual desktop.
  - Various bug fixes.
* Fri May 22 2009 meissner@suse.de
- Updated to upstream 1.1.22
  - More improvements to OLE copy/paste.
  - Beginnings of x86_64 exception handling.
  - Direct3D locking fixes.
  - ARB shaders improvements.
  - Better OpenGL pixel format support.
  - Various bug fixes.
* Fri May  8 2009 meissner@suse.de
- Updated to upstream 1.1.21
  - Beginnings of shader model 4 support.
  - Support for copying/pasting images from X11 applications.
  - A number of GDIPlus improvements.
  - Various listview fixes.
  - 64-bit support in winemaker.
  - Support for building on Mac OS X Snow Leopard.
  - Various bug fixes.
* Sun May  3 2009 meissner@suse.de
- Updated to upstream 1.1.20
  - Show a dialog on application crashes.
  - Much improved OLE copy/paste support.
  - Various listview improvements.
  - More Direct3D code cleanups.
  - Various bug fixes.
* Fri Apr 10 2009 meissner@suse.de
- Updated to upstream 1.1.19
  - Support for Visual C++ project files in winemaker.
  - Improvements to the Esound driver.
  - Many Direct3D code cleanups.
  - Fixes to OLE clipboard handling.
  - OpenBSD compilation fixed.
  - Various bug fixes.
* Thu Apr  2 2009 meissner@suse.de
- Updated to upstream 1.1.18
  - Joystick support on Mac OS X.
  - Implementation of iphlpapi on Solaris.
  - A number of 64-bit improvements.
  - Obsolete LinuxThreads support has been removed.
  - Many fixes to the regression tests on Windows.
  - Various bug fixes.
* Sat Mar 14 2009 meissner@suse.de
- Updated to upstream 1.1.17
  - Joystick support on Mac OS X.
  - Implementation of iphlpapi on Solaris.
  - A number of 64-bit improvements.
  - Obsolete LinuxThreads support has been removed.
  - Many fixes to the regression tests on Windows.
  - Various bug fixes.
* Sat Feb 28 2009 meissner@suse.de
- Updated to upstream 1.1.16
  - Improved SANE scanner support.
  - Support for digital CD audio playback.
  - Improved cookies management in Wininet.
  - Support for building stand-alone 16-bit modules.
  - Many fixes to the regression tests on Windows.
  - Various bug fixes.
- updated winetricks to current version
* Fri Feb 13 2009 meissner@suse.de
- Updated to upstream 1.1.15
  - Gecko engine update.
  - Better region support in GdiPlus.
  - Support for cross-compilation in winegcc.
  - Beginnings of MS Text Framework support.
  - Many fixes to the regression tests on Windows.
  - Various bug fixes.
* Tue Feb  3 2009 meissner@suse.de
- Updated to upstream 1.1.14
  - Various bug fixes for Internet Explorer 7.
  - Many crypt32 improvements, including new export wizard.
  - Better support for windowless Richedit.
  - Improvements to the print dialog.
  - Many fixes to the regression tests on Windows.
  - Various bug fixes.
- Updated winetricks
* Sun Jan 18 2009 meissner@suse.de
- Updated to upstream 1.1.13
  - Freedesktop.org-compliant startup notifications.
  - Many fixes for 64-bit application support.
  - Improved graphics support in Internet Explorer.
  - Various Richedit improvements.
  - Better certificate manager dialog.
  - Various bug fixes.
- Updated winetricks to current state.
* Fri Jan  2 2009 meissner@suse.de
- Updated to upstream 1.1.12
  - Some simple 64-bit apps should now run.
  - Support for subpixel font rendering.
  - 64-bit code generation in the IDL compiler.
  - New version of the Gecko engine.
  - Various bug fixes.
- updated winetricks
* Sat Dec 20 2008 meissner@suse.de
- Updated to upstream 1.1.11
  - Numerous fixes for IE7 support.
  - Support for 64-bit cross-compile using Mingw64.
  - User interface support for crypto certificates.
  - Better support for MSI installation patches.
  - Various Direct3D optimizations.
  - Various bug fixes.
* Fri Dec  5 2008 meissner@suse.de
- Updated to upstream 1.1.10
  - Support for virtual memory write watches.
  - Workarounds for the WINAPI compiler bug on Mac OS.
  - Several fixes for the 64-bit build.
  - Some more GdiPlus functions.
  - Various bug fixes.
* Fri Nov 28 2008 meissner@suse.de
- new winetricks
  - loaders for mono20, ole2, msmask, ie6
  - bugfixes for directx9
* Mon Nov 24 2008 meissner@suse.de
- Updated to upstream 1.1.9
  - A large number of regression test fixes.
  - Performance improvements in memory management.
  - Improved POP3 support in inetcomm.
  - Initial implementation of the XInput DLL.
  - Various bug fixes.
- hardrequire all the funny 32bit libraries against we link
- run suse_update_desktop_file bnc#445736
* Fri Nov  7 2008 meissner@suse.de
- Updated to upstream 1.1.8
  - Substantial parts of inetcomm implemented (for Outlook).
  - Still better crypt32 support.
  - Memory management improvements.
  - Theming support for buttons.
  - Various bug fixes.
* Fri Oct 24 2008 meissner@suse.de
- Updated to upstream 1.1.7
  - Improved device management for DOS drives.
  - Many Richedit fixes.
  - Various installer fixes, particularly for IE 7.
  - First steps of Direct3D 10 implementation.
  - Various bug fixes.
* Mon Oct 13 2008 meissner@suse.de
- Updated to upstream 1.1.6
  - Beginnings of schannel implementation using GnuTLS.
  - Many fixes from various code analysis tools.
  - Support for X11 desktop work area.
  - Fixes for Richedit tables.
  - More complete JavaScript support.
  - Various bug fixes.
- Requires gnutls-devel for schannel support
- small winetricks fixes
* Fri Sep 19 2008 meissner@suse.de
- Updated to upstream 1.1.5
  - Substantial JavaScript implementation.
  - Partial support for layered windows.
  - Support for Unicode file export in Regedit.
  - Proper exception handling in widl-generated code.
  - Asynchronous requests and cookies support in WinHTTP.
  - Various bug fixes.
* Sun Sep  7 2008 meissner@suse.de
- Updated to upstream 1.1.4
  - Substantial chunks of WinHTTP are implemented.
  - More JavaScript support.
  - Beginnings of shell AppBar implementation.
  - Several fixes for Google Chrome support.
  - Chinese translations.
  - Various bug fixes.
- Updated winetricks
* Fri Aug 22 2008 meissner@suse.de
- Updated to upstream 1.1.3
  - Beginnings of ddraw overlay support.
  - Many more crypt32 functions.
  - Improved support for tables in Richedit.
  - Support for NETWM window maximization.
  - Many installer fixes.
  - Tweaks for better PulseAudio support.
  - Various bug fixes.
- Updated to upstream 1.1.2
  - Control panel improvements and new appwiz panel.
  - Restructurations of state handling in Direct3D.
  - Support for timer queue functions.
  - Many MSXML improvements.
  - Several fixes to Solaris support.
  - Various bug fixes.
- Updated winetricks to current version
* Fri Aug 15 2008 ro@suse.de
- add exclusivearch to specfile
* Fri Jul 11 2008 meissner@suse.de
- Updated to upstream 1.1.1 - development release
  - Fixes for Photoshop CS3 and Office 2007 installers.
  - More progress on gdiplus.
  - Support for Unicode files in regedit.
  - Improved video playback.
  - Many Richedit fixes and improvements.
  - Various bug fixes.
- winetricks updated
  - ogg and schroeder/dirac codecs
  - Added firefox3, kde
  - Simpler recipe for msls31
  - sets win2k while installing vcrun2005.
  - Fixed DirectX9 install
  - Added visual j# 2.0 runtime
  - divx codec download location changed
  - Add comctl32.ocx
  - Added autohotkey
- Upgraded to upstream 1.1.0 - development release
  - Many more gdiplus functions implemented.
  - Improved graphics tablet support.
  - Many Richedit fixes and improvements.
  - Support for HWND_MESSAGE windows.
  - A lot of new MSHTML functions.
  - Many fixes in MSI registry handling.
  - Initial implementation of the inetmib1 DLL.
  - Improvements to the quartz renderers.
  - Various bug fixes.
* Tue Jun 17 2008 meissner@suse.de
- Upgraded to upstream 1.0 - first stable release
- updated winetricks
  - comctl32.ocx downloader added
  - dirac,vlc downloader
* Fri Jun 13 2008 meissner@suse.de
- Upgraded to upstream 1.0-rc5
  - Lots of bug fixes.
* Sun Jun  8 2008 meissner@suse.de
- Upgraded to upstream 1.0-rc4 (labeled 0.9.65_aka_1.0.rc4
  to avoid update problems to 1.0)
  - Bug fixes only, we are in code freeze.
- updated to current winetricks
  - added vlc,quicktime downloader and mplayerclient tool downloader
- Changelog only included in source tarball now
* Tue Jun  3 2008 meissner@suse.de
- Upgraded to upstream 1.0-rc3 (labeled 0.9.64_aka_1.0.rc4
  to avoid update problems to 1.0)
  - Bug fixes only, we are in code freeze.
- updated to current winetricks
  - bugfixes
* Fri May 23 2008 meissner@suse.de
- Upgraded to upstream 1.0-rc2 (labeled 0.9.63_aka_1.0.rc2
  to avoid update problems to 1.0)
  - Bug fixes only, we are in code freeze.
- merged in ulis fixes into local GIT
- updated to current winetricks
  - directx9 downloader (for the helper dlls)
  - bugfixes
  - mfc42 alias
* Fri May 16 2008 uli@suse.de
- always use -m32/--32/-m elf_i386, even on x86 (allows x86
  devel tools to work on AMD64)
- fixed invalid dsound assumption
* Sat May 10 2008 meissner@suse.de
- Upgraded to upstream 1.0-rc1 (labeled 0.9.62_aka_1.0.rc1
  to avoid update problems to 1.0)
  - Bug fixes only, we are in code freeze.
* Wed May  7 2008 meissner@suse.de
- removed fontforge, audiofile, libtiff-devel from buildrequires,
  added libjpeg-devel
- more winetricks bugfixes regarding fonts.
* Fri May  2 2008 meissner@suse.de
- Upgraded to upstream 0.9.61
  - Automatic updating of the WINEPREFIX directory.
  - Winhelp now uses Richedit as display engine.
  - Many RichEdit fixes.
  - More improvements to IME support.
  - More quartz fixes.
  - Implementation for many more Gdiplus functions.
  - Lots of bug fixes.
- updated winetricks to current version
  - bugfixes, mono fixes
* Sat Apr 19 2008 meissner@suse.de
- Upgraded to upstream 0.9.60
  - Better support for Windows IMEs.
  - Option for Windows-style window decorations.
  - Improved system tray behavior.
  - Window management fixes.
  - Improved quartz audio support.
  - Better support for launching apps from Unix file managers.
  - Lots of bug fixes.
- winetricks updated
  - various new downloads (wmp9,wmp10,..)
  - bugfixes
* Fri Apr  4 2008 meissner@suse.de
- Upgraded to upstream 0.9.59
  - Improved support for the .NET framework.
  - Better services handling through a separate services.exe process.
  - Support for ATI fragment shader.
  - Better support for http proxies.
  - Window management fixes.
  - Pre-compiled fonts are now available in the source tree.
  - Lots of bug fixes.
- winetricks updated
  - msls31, dotnet20, vcrun2003 downloaders added
  - bugfixes
* Fri Mar 21 2008 meissner@suse.de
- Upgraded to upstream 0.9.58
  - The default version is now Windows XP.
  - Many Richedit improvements.
  - Beginning of jscript dll support.
  - Shell folders now respect XDG directory configuration.
  - Many translation updates.
  - Lots of bug fixes.
* Wed Mar 12 2008 meissner@suse.de
- Upgraded to upstream 0.9.57
  - Support for multiple OpenGL pixel formats.
  - Improved support for color profiles.
  - Many window management fixes.
  - Better fullscreen support.
  - Lots of bug fixes.
- Updated winetricks
  - more visual basic runtimes downloaders added
  - MS dotnet 1.1 downloader added
  - added intel codec downloader
  - renamed allvcodecs -> allcodecs
* Fri Feb 22 2008 meissner@suse.de
- Upgraded to upstream 0.9.56
  - Proper handling of OpenGL/Direct3D windows with menu bars.
  - Stubs for all the d3dx9_xx dlls.
  - Several graphics optimizations.
  - Many installer fixes.
  - Improved MIME message support.
  - Lots of bug fixes.
- winetricks 20080222
  - colorprofile downloader added
* Mon Feb 11 2008 meissner@suse.de
- Upgraded to upstream 0.9.55
  - Direct3D improvements, including driver version emulation.
  - Beginnings of support for OLE objects in Richedit.
  - Several fixes to the animation control.
  - A bunch of fixes for regression test failures.
  - Lots of bug fixes.
- Updated winetricks
  - added msxml6, riched30
  - added GUI dialogs (using kdialog, etc.)
* Fri Jan 25 2008 meissner@suse.de
- Upgraded to upstream 0.9.54
  - Photoshop CS/CS2 should now work, please help us testing it.
    See http://wiki.winehq.org/AdobePhotoshop for details.
  - A number of RPC fixes.
  - Various improvements to the debugger support.
  - Lots of bug fixes.
- Updated winetricks
  - added mdac25, riched20, xvid, ffdshow, vcrun2005sp1, vcrun2008
  - new pseudo packages: allfonts, allvcodecs
  - mono12 now links to 1.2.6
* Sat Jan 12 2008 meissner@suse.de
- Upgraded to upstream 0.9.53
  - RunOnce and Run entries now executed on startup.
  - Beginnings of support for emulated disk devices.
  - Many Richedit improvements.
  - Nicer looking color dialog.
  - Lots of bug fixes.
* Fri Dec 28 2007 meissner@suse.de
- Upgraded to upstream 0.9.52
  - Improved graphics tablet support.
  - Support for RPC context handles.
  - Fixes for some longstanding screen depth issues.
  - Implementation of "My Network Places" shell folder.
  - Lots of bug fixes.
* Fri Dec 14 2007 meissner@suse.de
- Upgraded to upstream 0.9.51
  - A bunch of WinHelp improvements.
  - Better Japanese font support.
  - A ton of rpcrt4 fixes.
  - Several Alsa capture fixes.
  - Improved support for screen resolution changes.
  - Lots of bug fixes.
- Upgraded to upstream 0.9.50
  - Completed I/O completion.
  - Improved user credentials management, including Mac Keychain support.
  - More Valgrinding.
  - Lots of bug fixes.
- Updated winetricks
  - some mono 1.2 fixes
* Fri Nov  9 2007 meissner@suse.de
- Upgraded to upstream 0.9.49:
  - Many copy protection fixes.
  - GLSL is now the default for Direct3D.
  - Lots of memory errors fixed thanks to Valgrind.
  - Support for TOPMOST windows.
  - Beginnings of an inetcomm dll implementation.
  - Lots of bug fixes.
* Wed Oct 31 2007 ro@suse.de
- include assert.h for alsa source
* Fri Oct 26 2007 meissner@suse.de
- Upgraded to upstream 0.9.48:
  - Still more fixes for regression test failures.
  - Much more complete cryptnet implementation.
  - WIDL is now able to generate the oleaut32 proxy code.
  - Lots of bug fixes.
* Fri Oct 12 2007 meissner@suse.de
- Upgraded to upstream 0.9.47:
  - New scheme for OpenGL support in child windows.
  - Lots of fixes for regression test failures.
  - A Tahoma replacement font.
  - Lots of bug fixes.
* Sun Sep 30 2007 meissner@suse.de
- Upgraded to upstream 0.9.46:
  - A variety of fixes to improve Photoshop CS2 support.
  - More complete support for device installation in setupapi.
  - New Bidi text implementation that doesn't depend on libicu.
  - The usual assortment of Direct3D improvements.
  - Beginning of I/O completion ports support.
- Upgraded to upstream 0.9.45:
  - Many improvements to the crypto dlls (should make iTunes work).
  - The usual assortment of Direct3D improvements.
  - A number of fixes to sound support.
  - Many more WordPad features.
- New winetricks version
* Fri Aug 24 2007 meissner@suse.de
- Upgraded to upstream 0.9.44:
  - Better heuristics for making windows managed.
  - Automatic detection of timezone parameters.
  - Improvements to the builtin WordPad.
  - Better signatures support in crypt32.
  - Still more gdiplus functions.
  - Lots of bug fixes.
- New winetricks version
  - checksum verification for downloads
  - Add sha1sums for most downloads
  - Note a few downloads are no longer available (replacements, anyone?)
  - Note mono11 is deprecated
  - Add Mikolaj's nifty fakeie changes
* Fri Aug 10 2007 meissner@suse.de
- Upgraded to upstream 0.9.43:
  - Direct3D support on top of WGL instead of GLX for better portability.
  - Many DirectSound fixes.
  - Still more gdiplus functions.
  - Many crypt32 improvements.
  - Lots of bug fixes.
* Mon Jul 30 2007 meissner@suse.de
- Upgraded to upstream 0.9.42:
  - Support for activation contexts and side-by-side assemblies.
  - Many more gdiplus functions.
  - More messaging support in crypt32.dll.
  - Many HTTP protocol handling fixes.
  - Lots of bug fixes.
- updated README a bit
* Mon Jul 16 2007 meissner@suse.de
- Upgraded to upstream 0.9.41:
  - A number of gdiplus functions.
  - More complete pdh.dll implementation.
  - Support for MSI remote calls.
  - Messaging support in crypt32.dll.
  - Lots of bug fixes.
* Wed Jul  4 2007 meissner@suse.de
- Upgraded to upstream 0.9.40:
  - Many MSHTML improvements.
  - A few more sound fixes.
  - Many Direct3D fixes.
  - Lots of bug fixes.
- added some more buildrequires for splitted packages
* Sat Jun 23 2007 meissner@suse.de
- run fdupes, fixup desktop file to be more compliant.
* Fri Jun 15 2007 meissner@suse.de
- Upgraded to upstream 0.9.39:
  - Many MSHTML improvements.
  - Several improvements to the sound support.
  - A number of Winsock fixes.
  - Several new supported constructs in the IDL compiler.
  - Many Direct3D threading fixes.
  - Lots of bug fixes.
* Sat Jun  2 2007 meissner@suse.de
- Upgraded to upstream 0.9.38:
  - Beginnings of support for copy protection kernel drivers.
  - More MSI automation support.
  - Many 64-bit compilation fixes.
  - A number of OLE fixes.
  - Lots of bug fixes.
- Added "winetricks" script from Dan Kegel.
* Fri May 11 2007 meissner@suse.de
- Upgraded to upstream 0.9.37:
  - MSI automation with JScript/VBScript support.
  - Various MSHTML improvements.
  - The usual assortment of Direct3D fixes.
  - Support for a few more exe protection schemes.
  - Lots of bug fixes.
* Mon May  7 2007 meissner@suse.de
- removed duplicate Icon= line.
* Sun Apr 29 2007 meissner@suse.de
- Upgraded to upstream 0.9.36:
  - Midi support in the CoreAudio driver.
  - Mixer support in the Alsa driver.
  - A lot of MSI fixes.
  - Implementation for most D3DRM functions.
  - The usual assortment of Direct3D fixes.
  - Lots of bug fixes.
* Fri Apr 13 2007 meissner@suse.de
- Upgraded to upstream 0.9.35:
  - Broken aRts sound driver now removed for good.
  - Many fixes to the Quartz DLL sound support.
  - File I/O performance improvements.
  - The usual assortment of Direct3D fixes.
  - Lots of bug fixes.
- Upgraded to upstream 0.9.34:
  - Support for Xcursor.
  - A range of fixes for various installers.
  - New builtin xcopy tool.
  - Lots of bug fixes.
* Fri Mar 30 2007 meissner@suse.de
- buildrequires bison,flex,ncurses-devel
* Sat Mar 17 2007 meissner@suse.de
- Upgraded to upstream 0.9.33:
  - Many Direct3D fixes and performance improvements.
  - More comctl32 tests and some bug fixes.
  - Compatibility improvements in cmd.exe.
  - Still more fixes to builtin OLE.
  - Support for process control on Solaris.
  - Lots of bug fixes.
* Sat Mar  3 2007 meissner@suse.de
- Upgraded to upstream 0.9.32:
  - Many Direct3D fixes and performance improvements.
  - Several new features in the builtin cmd.exe.
  - Improvements to HTML help support.
  - Lots of bug fixes.
* Tue Feb 20 2007 meissner@suse.de
- Upgraded to upstream 0.9.31:
  - Many Direct3D fixes and performance improvements.
  - Several new comctl32 test cases.
  - IDL compiler improvements.
  - More OLE32 marshalling fixes.
  - Lots of bug fixes.
* Thu Jan 25 2007 meissner@suse.de
- Upgraded to upstream 0.9.30:
  - Many improvements to Direct3D shaders and state management.
  - Support for inter-process memory allocations.
  - OLE32 marshalling fixes.
  - Lots of bug fixes.
* Wed Jan 10 2007 meissner@suse.de
- Upgraded to upstream 0.9.29:
  - More work on the new Direct3D state management.
  - Debugger support for Mac OS.
  - Many OLE fixes and improvements.
  - Audio input support on Mac OS.
  - Lots of bug fixes.
* Thu Jan  4 2007 meissner@suse.de
- Upgraded to upstream 0.9.28:
  - OpenGL in child windows should work again.
  - Better mouse support in games.
  - Beginnings of new state management in Direct3D.
  - Improved audio and font support on Mac OS.
  - Lots of bug fixes.
* Sat Dec  9 2006 meissner@suse.de
- removed labels.patch
- Upgraded to upstream 0.9.27:
  - Better support for noexec kernels.
  - Better Dwarf support in dbghelp.
  - Several Winsock fixes.
  - Various code cleanups.
  - Lots of bug fixes.
* Fri Dec  8 2006 meissner@suse.de
- Upgraded to upstream 0.9.26:
  - Better support for Unix locale settings.
  - Improved X11 keyboard support.
  - Various MSI fixes.
  - Winecfg improvements.
- Upgraded to upstream 0.9.25:
  - Many more fixes for installer support.
  - Many MSHTML improvements.
  - Support for NTLMv2.
  - RPC over TCP improvements.
* Sat Nov 25 2006 meissner@suse.de
- handle labels with spaces inside during setup of prefix #223681
* Fri Oct 27 2006 meissner@suse.de
- buildrequires libgphoto2-devel
- Upstream 0.9.24:
  - Support for multiple monitors using Xinerama.
  - Various MSI fixes and improvements.
  - A ton of memory leaks fixed.
  - Many common controls fixes.
  - Lots of bug fixes.
* Mon Oct 16 2006 meissner@suse.de
- Upstream 0.9.23:
  - Massive update of printf formats for Win64 compatibility.
  - Dynamic drive support on MacOSX.
  - Still more MSI fixes and improvements.
  - Lots of bug fixes.
* Thu Sep 28 2006 meissner@suse.de
- Upstream 0.9.22:
  - The usual assortment of MSI improvements.
  - Several bug fixes to the various common controls.
  - Pixel shaders enabled by default in D3D.
  - Various improvements to the build process.
  - Many translation updates.
  - Lots of bug fixes.
* Thu Sep 14 2006 meissner@suse.de
- Upstream 0.9.21:
  - OpenGL restructurations.
  - The usual assortment of MSI improvements.
  - Several Richedit fixes.
  - WCMD Winelib app renamed to CMD for compatibility.
  - Many improvements to the Wintrust DLL.
  - Some code cleanups.
  - Lots of bug fixes.
- Merged my local patch into tarball, dropped
  some no longer necessary old stuff.
* Thu Aug 24 2006 meissner@suse.de
- Upstream 0.9.20:
  - XEmbed system tray support.
  - Many improvements to NTLM support.
  - Many messages made localizable instead of hardcoded to English.
  - Improved support for various OpenGL platforms.
  - More improvements to the IDL compiler.
  - Lots of bug fixes.
- Switched back to OSS by default. ALSA causes hangs
  in DirectSound :(
* Mon Aug 14 2006 meissner@suse.de
- Upstream 0.9.19:
  - Support for a proper Trash folder.
  - Many improvements to the IDL compiler.
  - Better FreeBSD support.
  - A number of MSI bug fixes.
  - Many RichEdit improvements.
  - Lots of bug fixes.
* Fri Jul 28 2006 meissner@suse.de
- Upstream, 0.9.18:
  - Still more work on Direct3D.
  - A lot of MSI bug fixes and improvements.
  - More compatible memory management.
  - Several fixes for Win64 support.
  - Some performance improvements.
  - Lots of bug fixes.
* Thu Jul 13 2006 meissner@suse.de
- Upstream 0.9.17:
  - Still more work on Direct3D shaders.
  - Now using the Gecko engine directly for MSHTML.
  - Better support for apps switching to full screen mode.
  - Support for multiple joysticks.
  - Lots of bug fixes.
- Upstream 0.9.16:
  - More work on Direct3D shaders.
  - Major DirectDraw rewrite on top of Direct3D.
  - Support for debug information in Dwarf format.
  - Beginnings of an OleView Winelib application.
  - Lots of bug fixes.
- personality patch no longer necessary.
* Thu Jun  8 2006 meissner@suse.de
- Upstream 0.9.15:
  - More MS/RPC improvements.
  - Core Audio driver for Mac OS X.
  - More complete DNSAPI dll.
  - Improvements to Web browser support.
  - Lots of bug fixes.
* Thu May 25 2006 meissner@suse.de
- Upstream 0.9.14
  - Better MS/RPC compatibility.
  - Many fixes to Direct3D shaders.
  - Several improvements to the header control.
  - Lots of bug fixes.
* Mon May 15 2006 meissner@suse.de
- Upstream 0.9.13
  - New GPhoto backend for TWAIN.
  - Dynamic drive configuration using HAL.
  - A gazillion Direct3D fixes.
  - New TCP transport for RPC.
  - Lots of bug fixes.
- Added libgphoto2 and hal development libs to BuildRequires.
- personality hack to avoid virtual ram ulimits now seperate.
* Mon Apr 17 2006 meissner@suse.de
- Upstream 0.9.12:
  - New Winelib Internet Explorer application (all 5 lines of it).
  - Several improvements to the font support.
  - More work on the IDL compiler.
  - Faster drawing of the cards in Solitaire (very important feature).
  - A number of fixes for issues found by the Coverity code cheker.
  - Lots of bug fixes.
* Tue Apr 11 2006 meissner@suse.de
- upstream 0.9.11:
  - Fake dll files created in the system directory to help installers.
  - Desktop mode now properly supports multiple processes.
  - Better type parsing in dbghelp.
  - Several OpenGL fixes.
  - A bunch of Unicode functions in advpack.
  - Lots of bug fixes.
- upstream 0.9.10:
  - Improved ESD audio driver.
  - More Web browser improvements in mshtml and wininet.
  - Direct3D fixes and preparation for ddraw code migration.
  - Explorer process now managing the desktop window.
  - Lots of bug fixes.
- upstream 0.9.9:
  - Many new features and improvements in Richedit.
  - More Web browser support.
  - Recursive directory change notifications.
  - Wine installation is now fully relocatable.
  - Direct3D 8 and 9 now use the same code.
  - Many debugger improvements.
  - Systray is now handled by the explorer process.
  - Lots of bug fixes.
- upstream 0.9.8:
  - Better Web browser support.
  - Beginnings of a Wordpad application.
  - Many richedit improvements.
  - A number of Direct3D fixes.
  - A few more options in winecfg.
  - Lots of bug fixes.
- upstream 0.9.7:
  - Directory change notifications can use inotify now.
  - Hardware breakpoints in the Wine debugger.
  - Beginnings of support for tape APIs.
  - A bunch of improvements to the IDL compiler.
  - Better scheme for mapping My Documents etc. to Unix directories.
  - Lots of bug fixes.
- upstream 0.9.6:
  - A bunch of OLE fixes and improvements.
  - DirectSound improvements, including full duplex support.
  - Fix for the Windows metafile vulnerability.
  - Many static control improvements.
  - Some fixes for copy protection support.
  - Lots of bug fixes.
* Fri Mar 17 2006 meissner@suse.de
- Avoid ulimit leading to out of memory situations by using
  the compat address space layout personality. #152115
* Fri Mar 17 2006 meissner@suse.de
- Select ALSA by default. #158424
* Mon Feb  6 2006 meissner@suse.de
- Handle empty /media/ gracefully. #148351
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 meissner@suse.de
- fixed WMF explpoit here too.
* Mon Jan  9 2006 meissner@suse.de
- backport patch from CVS that fixes hang with installshield 6 installers.
* Wed Jan  4 2006 meissner@suse.de
- Upgraded to 0.9.5 release:
  - A number of MSI fixes.
  - More improvements to the IDL compiler.
  - Lots of bug fixes.
* Wed Dec 28 2005 meissner@suse.de
- Upgraded to 0.9.4 release:
  - Improvements to the IDL compiler.
  - Some infrastructure work for loadable driver support.
  - The usual assortment of Direct3D improvements.
  - IME support in the edit control.
  - Better support for AVI animations.
  - Debugging support improvements.
  - Relay traces now work on NX platforms.
  - Lots of bug fixes.
- tcl,tcl-devel not neededforbuild.
* Thu Dec  8 2005 meissner@suse.de
- Upgraded to 0.9.3 release:
  - Many marshalling fixes in rpcrt4.
  - Various OLE improvements and fixes.
  - Better audio driver management in winecfg.
  - Many wininet fixes.
  - Several Web browser improvements.
  - More dbghelp APIs implemented.
  - Directory objects in wineserver.
  - Lots of bug fixes.
* Tue Nov 22 2005 meissner@suse.de
- Upgraded to 0.9.2 release:
  - Winelib Explorer app (just a wrapper around winefile for now).
  - Debugger cleanups and improvements.
  - Many wininet fixes.
  - Better autogenerated API manpages.
  - A bunch of Korean translations.
  - Lots of bug fixes.
* Fri Nov 11 2005 meissner@suse.de
- Upgraded to 0.9.1 release:
  - Support for Find function in regedit.
  - Winelib app to eject a CD.
  - Many MSI improvements.
  - Better support for running text-mode apps without X.
  - Improved support for various code obfuscation tools.
  - Lots of bug fixes.
* Tue Oct 25 2005 meissner@suse.de
- Upgraded to 0.9 release (first BETA release).
* Fri Sep 30 2005 meissner@suse.de
- upgraded to 20050930 release:
  - Joystick force feedback support.
  - Beginnings of Win64 support.
  - Many MSI fixes and cleanups.
  - Font linking support.
  - Several OLE fixes.
  - Some fixes for MacOS/x86.
  - Lots of bug fixes.
* Sun Sep 25 2005 meissner@suse.de
- fixed deprecated LDAP stuff.
* Fri Sep 16 2005 meissner@suse.de
- added pkgconfig, prelink to nfb
- Upgraded to 20050830 release:
  - A lot more theming support.
  - Many improvements to the various crypto dlls.
  - More LDAP support.
  - Beginnings of an MSXML implementation.
  - Better MSHTML support.
  - Emulated version now set to Windows 2000 by default.
  - Direct3D fixes and improvements.
  - Lots of bug fixes.
* Sun Aug  7 2005 meissner@suse.de
- fixed build with new fontforge.
* Sat Jul 30 2005 meissner@suse.de
- Upgraded to final 20050725 release:
  - Beginnings of theme support in common controls.
  - Many MSHTML improvements.
  - A bunch of OLE fixes for InstallShield installers.
  - Many Direct3D fixes and improvements.
  - Beginnings of LDAP support.
  - Various cleanups after removal of the config file.
  - Lots of bug fixes.
* Fri Jul 22 2005 meissner@suse.de
- upgraded to current CVS
  - InstallShield installers in general now works!
  - some 16bit fixes for old 16bit OLE using programs.
  - lots of other bugfixes.
- disabled one msacm codec.
* Wed Jun 29 2005 meissner@suse.de
- Upgraded to 20050628 release:
  - Configuration settings moved to the registry.
  - Graphical Wine configuration tool is now enabled.
  - More MSI and OLE improvements.
  - Reorganisation of the DirectDraw directory.
  - Initial support for webcams.
  - Lots of bug fixes.
- No more ~/.wine/config file, all in the registry now.
* Fri Jun 17 2005 meissner@suse.de
- fixed a detected buffer overflow.
* Mon May 30 2005 meissner@suse.de
- Upgraded to 20050524 release:
  - Many MSI improvements.
  - More features in the file manager.
  - Better compatibility for Winelib import libraries.
  - SGML documentation moved out of the source tree.
  - Header files cleanups.
  - Lots of bug fixes.
* Wed May 18 2005 ro@suse.de
- fix build with most recent alsa includes
* Thu Apr 28 2005 meissner@suse.de
- fixed buffer overflows.
* Wed Apr 20 2005 meissner@suse.de
- Upgraded to 20050419 release.
  - Mailslot support.
  - Support for side mouse buttons (X buttons).
  - More Richedit improvements.
  - Loading of Windows registry files disabled for now.
  - Many code cleanups.
  - Lots of bug fixes.
* Wed Apr 13 2005 meissner@suse.de
- Upgraded to 20050310 release.
  - Initial implementation of a true Richedit control.
  - Shell extension for browsing Unix directories.
  - More MSI work.
  - PBuffer support in OpenGL.
  - Window painting regressions should be fixed.
  - Lots of bug fixes.
- Updated to CVS head branch.
- Reenabled mp3.
- Fixed gcc4 problems.
* Mon Feb 21 2005 meissner@suse.de
- add desktop-file-utils and glib2 to neededforbuild, since
  update-desktop-database is called.
* Mon Feb 14 2005 meissner@suse.de
- Upgraded to 20050211 release:
  - Still more work on the MSI dll.
  - More OLE work, including a builtin stdole32.tlb.
  - Fixed inter-process window resize and repaint.
  - Lots of bug fixes.
- Includes bugfix for 2.6.11 kernels with NX mapping.
- stdole32.tlb still included.
* Wed Jan 19 2005 meissner@suse.de
- Fixed README.SuSE
* Wed Jan 12 2005 meissner@suse.de
- Upgraded to 2005011 release:
  - Many OLE bug fixes and improvements.
  - A lot more work on the MSI dll.
  - Update regions now handled in the Wine server.
  - Beginnings of typelib generation in the IDL compiler.
  - Many janitorial cleanups.
  - Lots of bug fixes.
- No hard dependency on libcapi.so.20 anymore.
* Thu Dec  2 2004 meissner@suse.de
- Upgraded to 20041201 release:
  - Implementation of the RSAENH dll.
  - More work on the Direct3D 9 architecture.
  - Builtin debugger improvements.
  - Reorganisation of the Developer's Guide.
  - Lots of bug fixes.
- Dropped no longer needed call to wineprefixcreate,
  wine now does it itself.
* Thu Nov 11 2004 ro@suse.de
- fixed file list
* Wed Oct 20 2004 meissner@suse.de
- Upgraded to 20041019 release:
  - Beginnings of an architecture for Direct3D 9 support.
  - Many debugger regressions fixed.
  - Improvements to the IDL compiler and the COM headers.
  - New MSCMS dll (color management support).
- Upgraded to 20040918 release:
  - Various improvements to the common controls.
  - New ITSS dll (for HTML Help support).
  - Many compatibility fixes in the exported headers.
  - Replacements for the Windows standard bitmap fonts.
  - Lots of bug fixes.
- Create serial / lpt1 device links in wineprefixcreate.
- Added liblcms, liblcms-devel and fontforge to neededforbuild.
* Sun Oct  3 2004 meissner@suse.de
- Do not output localized floats into the PostScript data
  generated by WINEPS.
* Tue Sep 28 2004 meissner@suse.de
  FrameMaker 7 fixes:
- Make menuentries work (by upgrading dlls/shell32/shellpath.c to
  current CVS).
- Remove -- from generated shell links (no longer handled by WINE).
- Create some additional directories in the fake windows tree required
  by FrameMaker.
- Fixed creation of "x: -> /tmp", "y: -> $HOME" and CDROM links.
* Fri Sep 17 2004 meissner@suse.de
- Detect libgif shared library too, so OLEAUT can load GIF
  images again.
* Tue Sep 14 2004 meissner@suse.de
- Make menu entries appear again (fixed icondir handling) #43415
- Do not use /SuSE/ menu insert, the SuSE menu is no longer.
* Tue Aug 17 2004 meissner@suse.de
- Fixed compile with __user.
* Mon Aug 16 2004 meissner@suse.de
- Upgraded to 20040813 upstream release:
  - New msiexec application.
  - Support for alpha blending.
  - More sound support improvements.
  - Various code cleanups.
  - Lots of bug fixes.
* Mon Jul 19 2004 meissner@suse.de
- Upgraded to 20040716 upstream release:
  - Implementation of the Microsoft Installer dll.
  - Beginnings of proper inter-process window repaints.
  - Several DirectSound improvements.
  - Fixes for the regressions caused by the new filesystem support.
  - Lots of bug fixes.
* Fri Jun 18 2004 meissner@suse.de
- Upgraded to 20040615 upstream release:
  - Major winedbg rewrite using the dbghelp dll.
  - New Wine preloader to reserve memory areas at startup.
  - Many improvements to the audio support.
  - Lots of bug fixes.
* Tue May 11 2004 meissner@suse.de
- Upgraded to 20040505 upstream release:
  - Many more filesystem improvements, including autodetection
    of drive types and devices, and support for editing the drive
    configuration with winecfg.
  - Many Direct3D improvements.
  - Several fixes to the various sound drivers.
  - Lots of bug fixes.
- Dropped our own make_fakewindows setup, use wineprefixcreate instead.
* Tue Apr 20 2004 meissner@suse.de
- Dropped winesetuptk, it is more and more unhelpful to the
  ongoing wine configuration file changes.
- Cleaned spec file.
- Upgraded to 20040408 upstream release:
  - DOS devices and drives are now configured through symlinks.
  - Many shell32 improvements.
  - New task manager merged from ReactOS.
  - First version of wineprefixcreate tool for initial setup.
  - Lots of bug fixes.
- Upgraded to 20040309 upstream release:
  - Much improved winegcc tool, now used to build Wine itself.
  - VxDs are now separate libraries for better modularity.
  - Improvements and simplifications to the drive configuration.
  - New setupapi INF script to create the initial registry.
  - Many improvements to the various multimedia dlls.
  - Lots of bug fixes.
* Mon Feb 16 2004 meissner@suse.de
- updated to 20040213 upstream release:
  - Improved support for screen resolution changes.
  - More shell32 improvements.
  - Several Winelib compatibility fixes.
  - Beginnings of support for typelib creation.
  - Lots of bug fixes.
- make_fakewindows now calls regsvr32 for all self registering
  dlls.
* Thu Jan 22 2004 meissner@suse.de
- updated to 20040121 upstream release:
  - Many improvements in the shell32 dll.
  - Better support for constructors in C++ Winelib apps.
  - Improved Regedit tool.
  - Full support for graphic tablets.
  - Lots of DirectMusic improvements.
  - Better support for video playback.
  - Full IME support for Asian locales.
  - Lots of bug fixes.
* Sun Dec 14 2003 meissner@suse.de
- removed config-dist.sh
- reenabled alsa/alsa-devel.
- updated to 20031212 upstream release:
  - Initial implementation of XDND drag&drop support.
  - Improved startup performance on remote displays.
  - Major improvements in the oleaut32 dll.
  - Some support for Netbios functions.
  - Work around for Exec Shield and prelinking troubles.
  - Many code cleanups.
  - Lots of bug fixes.
* Thu Nov 20 2003 meissner@suse.de
- update to 20031118 upstream release
  - Many printing improvements.
  - Run-time detection of NPTL threading.
  - Lots of code merges from Crossover Office 2.1.
  - Some reorganization of the source tree.
  - Lots of bug fixes.
- Added capi4linux, expat requires.
- Disabled alsa for now due to changed API.
* Fri Oct 17 2003 meissner@suse.de
- build as non root
- Upgraded to latest upstream:
  - Support for the Xrandr extension.
  - Dll separation of kernel and ntdll is finished.
  - Many enhanced metafile improvements.
  - Many improvements to the winecfg configuration tool.
  - Massive header files cleanup for better source compatibility.
  - Lots of bug fixes.
* Thu Sep 18 2003 adrian@suse.de
- unbreak build again
* Thu Sep 18 2003 adrian@suse.de
- hide menu entry, we need it still for MimeType handling
* Sun Sep 14 2003 adrian@suse.de
- include a wine.desktop file with correct Icon= line
* Fri Sep 12 2003 meissner@suse.de
- Do not use the greek/symbol font of koffice-wordprocessing
  as default truetype font.
* Mon Sep  1 2003 mmj@suse.de
- Fix head/tail syntax [#29622]
* Mon Aug 25 2003 meissner@suse.de
- Fix winewrap default path to /usr/lib/wine #29069
* Sat Aug 16 2003 adrian@suse.de
- install desktop file from kappfinder
* Tue Aug 12 2003 meissner@suse.de
- Upgraded to latest release 20030813:
  - Partial implementation of the Microsoft Installer (msi.dll).
  - GUI for regedit (from ReactOS).
  - DirectMusic dlls reorganization.
  - Many Wininet improvements.
  - Lots of bug fixes.
- fixed symlinks for .exe files in fake windows setup.
- removed one confusing message.
- skip broken truetype font, silence error messages with missing font dirs.
- added winemenubuilder, rundll32 to list of programs.
* Thu Jul 10 2003 meissner@suse.de
- New upstream release 20030709:
  - Still more Direct3D and DirectSound improvements.
  - Inter-process clipboard support.
  - Locale handling improvements.
  - More progress on the kernel/ntdll separation.
  - Lots of bug fixes.
* Mon Jun 23 2003 meissner@suse.de
- New upstream release:
  - Still more Direct3D and DirectSound improvements.
  - Tons of fixes merged from Crossover Office 2.0.
  - New iphlpapi dll.
  - Lots of bug fixes.
* Thu Jun 12 2003 meissner@suse.de
- package documentation main directory too.
* Fri May 23 2003 meissner@suse.de
- remove CVS dirs.
* Wed May 14 2003 meissner@suse.de
- Upgraded to the last release snapshot:
  - Some more reorganizations of the source tree.
  - A few more steps towards kernel/ntdll separation.
  - Many Direct3D improvements.
  - More compatible COM interfaces definitions.
  - Lots of bug fixes.
- package wine.m4 into wine-devel.
* Thu Apr 10 2003 meissner@suse.de
- Upgraded to the last release snapshot:
  - Some reorganizations of the source tree.
  - File change notifications.
  - Support for all variants of glibc 2.3.
  - Many documentation updates.
  - Many Direct Sound improvements.
  - File locking support.
  - Progress on kernel/ntdll dll separation.
  - Better dead keys support.
  - Many debugger fixes.
  - More Direct3D work.
  - Lots of bug fixes.
- Dropped my glibc 2.3 patches, they are now included.
* Tue Apr  1 2003 ro@suse.de
- use mesa-devel-packages in neededforbuild
* Fri Mar  7 2003 meissner@suse.de
- CUPS_SONAME/SONAME_CUPS was swapped, we were not finding CUPS
  on systems without cups-devel and so unable to print.
* Mon Mar  3 2003 meissner@suse.de
- Do not output that debugging info on every keypress
- dropped no longer needed SetParent optimization hack.
* Mon Feb 17 2003 meissner@suse.de
- Upgraded to current CVS.
- InstallShield v6 should be fixed again.
* Mon Feb 10 2003 meissner@suse.de
- New configuration method. We no longer call winesetup,
  but use a quick and dirty shell script for fake windows
  setup.
- Split sources into vanilla CVS tarball and SuSE patch.
* Mon Jan 27 2003 meissner@suse.de
- Make WINE work on STABLE again by no longer overloading
  __errno_location, but overwriting it instead. (This will
  break again as soon as TLS support is enabled for glibc.)
- Upgraded to current CVS.
* Thu Jan 23 2003 meissner@suse.de
- Upgraded to current CVS, which includes fixes for gcc 3.3 build
  and winewrapper.
* Fri Jan 17 2003 meissner@suse.de
- Upgraded to current CVS:
  - Much better header files compatibility in Winelib.
  - A ton of Direct3D work.
  - Many improvements in sound support.
  - New wineboot tool to simulate a Windows reboot.
  - Lots of bug fixes.
- Added libungif, jack, jack-devel, mesaglu, mesaglu-devel to neededforbuild.
- Added iwidgets to requires.
* Wed Jan  8 2003 meissner@suse.de
- Upgraded to current CVS:
  - DLL linking now done through import libraries.
  - A couple of new tools to make Winelib easier to use.
  - Many Direct3D improvements.
  - Improved Windows compatibility of the regression tests.
  - Finished conversion to STRICT compilation mode.
  - WinHelp revival.
  - Client-side fonts supported even without RENDER extension.
  - Regression tests no longer require Perl.
  - Lots and lots of bugfixes and other new features.
* Wed Nov 20 2002 meissner@suse.de
- Upgraded to current CVS.
- Some type punning warnings fixed.
- Merged WineHQ default config file into winesetup configfiles.
* Wed Nov 13 2002 meissner@suse.de
- Updated to new upstream version.
* Tue Nov 12 2002 ro@suse.de
- updated neededforbuild: jade_dsl,sp -> openjade,opensp
-         xshared,xdevel -> x-devel-packages
* Thu Oct 10 2002 meissner@suse.de
- Updated to new upstream version:
  - Massive listview rewrite.
  - New MS RLE codec.
  - winemaker should be working again.
  - Beginnings of Direct3D 8 support.
  - Lots of bugfixes.
* Wed Sep 18 2002 meissner@suse.de
- Reduced afmfiles by the one already included in the wineps driver itself.
- include a stdole32.tlb so InstallShield v6 might work.
- Fixed wine_set_default_reg script.
- Make the winesetup stuff also merge the default windows registry
  if we are running on a fake windows installation.
- Updated to new Upstream version:
  - Much improved PowerPC support
  - More correct locale definitions.
  - Progress on the conversion of handle types to pointers.
  - Many Visio and Quicken fixes merged from Crossover.
  - More OLE and shell improvements.
  - NAS and AudioIO sound drivers.
  - Still more Sparc portability fixes.
* Mon Sep  9 2002 meissner@suse.de
- If there is an existing windows install, still prefer the fake install
  since it is way less dangerous #19222.
- Use managed mode by default (so windows are just normal KDE windows)
* Mon Sep  2 2002 meissner@suse.de
- Do not suggest installing KDE menus of winesetup (they are not
  there and wine does its own now). #18648.
* Sun Sep  1 2002 ro@suse.de
- Use ExclusiveArch instead of BuildArch
* Thu Aug 29 2002 meissner@suse.de
- Change location of menu entries from /Wine/ to /SuSE/Wine/ to
  make the registered apps appear in the menu.
- Try to support biarch build for compiling on x86_64.
* Mon Aug 12 2002 meissner@suse.de
- Upgraded to current CVS snapshot (20020812)
- Upstream summary:
  - Beginnings of an IDL compiler.
  - Several new winedbg features.
  - More OLE and shell improvements.
  - DirectSound 8 and DirectInput 8 support.
  - Many OLE improvements.
  - Support for font downloading in Postscript driver.
  - ALSA sound driver.
  - Lots of bug fixes.
- Local:
  - Started enhancing PPC port.
* Sun Jul 28 2002 kukuk@suse.de
- remove libz from neededforbuild
* Wed Jul 10 2002 meissner@suse.de
- Upgraded to current CVS snapshot (20020710),
  lots of bugfixes inside.
- Tried fixing a Lotus Notes problem with the attachment information
  window.
* Mon Jun 17 2002 meissner@suse.de
- Upgraded to current CVS snapshot (20020614),
  lots of new features, bugfixes et.al.
- Tweaked wine_init so it does not recursively call itself.
* Tue Apr  9 2002 meissner@suse.de
- Upgraded to current CVS snapshot (20020409),
  contains a lot of fixes from upstream (including parts of the CrossOver
  Office patches)
- neededforbuild jpeg -> libjpeg, added kdelibs stuff to support
  arts client, added sane for twain32.dll
* Tue Feb  5 2002 pmladek@suse.cz
- added warning message into winesetup [#12932]
- added the same message also into README.SuSE
* Fri Feb  1 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Mon Jan 28 2002 pmladek@suse.cz
- removed old wine.systemreg, wine.userreg, there are newer in winesetuptk
- removed old generic*.ppd and used the newer one from the wine sources
- fixed ppd configuration in default config files [#12934]
- wine_set_default_reg updates windows registry also from
  the file psdrv.reg now
- winedefault.reg and psdrv.reg moved to /usr/lib/wine/reg
- tested print from wine
- updated README.SuSE
- cleanded up spec file
* Tue Jan 22 2002 pmladek@suse.cz
- updated wine to the latest snapshot 20011226
- updated winesetuptk to version 0.5.1b:
  * improved detection of windows partitions
  * drives in fstab are not automounted anymore
  * support for "auto" fs type (look for windows)
  * application specific profile support
  * application profile for Internet Explorer and Lotus Notes R5
  * preserve drive order like it's known under Windows
- WineSetupTk did not linked against static Tcl/Tk/Itcl libraries,
  instead of it was used old Makefile and old launcher
* Mon Dec  3 2001 ro@suse.de
- fixed neededforbuild <docbktls> to <docbook-toys>
* Thu Nov  1 2001 bjacke@suse.de
- make sub package -devel
- add "cups-devel cups-libs libpng jpeg openssl libtiff" to
  neededforbuild for CUPS support
- neededforbuild freetype2, -devel to support this
- remove xf86 from Requires (X libs are autorequired)
- remove Wine provides
- fixed to not provide man and doc directories
* Mon Sep 24 2001 pmladek@suse.cz
- fixed documentation - added docbook_4 again
* Tue Sep 18 2001 pmladek@suse.cz
- fixed warning messages on start up
* Mon Aug 27 2001 pmladek@suse.cz
- fixed to compile:
  * removed docbook_4 from #neededforbuild
- fixed path to documentation by installation
* Fri Aug 24 2001 pmladek@suse.cz
- updated to version 20010731
- added detection of version of wine config
- fixed autorun of winesetup when config does not exist or
  it is for bad version of wine
- fixed default configuration generated by winesetup along
  example in wine
- new script for registry updating
- fixed licence tag
- fixed README.SuSE
* Tue Aug 21 2001 ro@suse.de
- neededforbuild: replaced sp_libs with sp
* Mon May  7 2001 pmladek@suse.cz
- fixed error message from find command when winesetup starts
* Sun Apr 29 2001 pmladek@suse.cz
- fixed README.SuSE
* Thu Apr 26 2001 pmladek@suse.cz
- added itcl to requires (it isn't in default selections but
  it's needed by winesetup)
* Tue Apr 10 2001 pmladek@suse.cz
- updated to version 20010326
- fixed winesetup through changes in wine config
  - paths to afm files in config now
  - another declaration of default load order
- fixed README.SuSE
* Thu Mar 29 2001 ro@suse.de
- fixed neededforbuild
* Tue Mar 27 2001 pmladek@suse.cz
- returned flag --sysconfdir=/etc to configure (my bug)
* Tue Mar 27 2001 pmladek@suse.cz
- added URL
- repaired licence tag
- wine up-dated to the version 20010305
- added winesetuptk version 0.5.1b
- fixed winesetuptk for SuSE distribution
- added support: If you have no config file then 'winesetup'
  will be launched automatically when you launch 'wine'
  (fixed bug #6769)
- bziped sources
- actualized README.SuSE
- actualized description in PAC files
- generated html documentation from sgml documentation
- removed sgml documentation from binary rpm
- cleaned up spec file
* Thu Mar  8 2001 uli@suse.de
- renamed mesadev -> mesa-devel in neededforbuild
* Wed Feb  7 2001 uli@suse.de
- fixed for glibc 2.2.1
* Fri Dec  8 2000 uli@suse.de
- update -> 20001202
- added regapi
- added wine.systemreg and wine.userreg
- added afm and ppd files for printing
- added afm and ppd sections to wine.conf
* Thu Nov 23 2000 arvin@suse.de
- changed spec file to use a buildroot
- fixed group tag
* Tue Sep 26 2000 ro@suse.de
- removed bogus requires
- added mesa-stuff to neededforbuild
* Mon Sep 25 2000 hhetter@suse.de
- updated to 20000821
* Thu Jul 27 2000 arvin@suse.de
- changed wine.conf to noreplace
* Mon May 15 2000 bk@suse.de
- updated to version 20000430
* Mon Apr 17 2000 bk@suse.de
- updated to version 20000326
- added all new files to filelist
- use RPM_OPT_FLAGS as CFLAGS
* Fri Jan 28 2000 bg@suse.de
- new version 20000109
- moved /usr/man to /usr/share/man
* Sun Oct 17 1999 ro@suse.de
- fixed neededforbuild
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Jul 20 1999 mkraft@suse.de
- new version 990704
* Thu Apr  1 1999 uli@suse.de
- new version 990328
* Mon Mar 29 1999 rolf@suse.de
- new version 990314
* Tue Dec  1 1998 rolf@suse.de
- new version 981108
* Fri Jun 26 1998 rolf@suse.de
- new version 980614
* Thu Jan 15 1998 rolf@suse.de
- new version 980104
